pub struct DatasetService { /* private fields */ }dataset-service only.Expand description
Implements a client for the Vertex AI API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = DatasetService::builder().build().await?;
let parent = "parent_value";
let mut list = client.list_datasets()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
The service that manages Vertex AI Dataset and its child resources.
Configuration
To configure DatasetService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://aiplatform.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
DatasetService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap DatasetService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl DatasetService
impl DatasetService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for DatasetService.
let client = DatasetService::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: DatasetService + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: DatasetService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn create_dataset(&self) -> CreateDataset
pub fn create_dataset(&self) -> CreateDataset
Creates a Dataset.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::model::Dataset;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &DatasetService, parent: &str
) -> Result<()> {
let response = client.create_dataset()
.set_parent(parent)
.set_dataset(
Dataset::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_dataset(&self) -> GetDataset
pub fn get_dataset(&self) -> GetDataset
Gets a Dataset.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &DatasetService, name: &str
) -> Result<()> {
let response = client.get_dataset()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_dataset(&self) -> UpdateDataset
pub fn update_dataset(&self) -> UpdateDataset
Updates a Dataset.
Example
use google_cloud_wkt::FieldMask;
use google_cloud_aiplatform_v1::model::Dataset;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &DatasetService, name: &str
) -> Result<()> {
let response = client.update_dataset()
.set_dataset(
Dataset::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_datasets(&self) -> ListDatasets
pub fn list_datasets(&self) -> ListDatasets
Lists Datasets in a Location.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &DatasetService, parent: &str
) -> Result<()> {
let mut list = client.list_datasets()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn delete_dataset(&self) -> DeleteDataset
pub fn delete_dataset(&self) -> DeleteDataset
Deletes a Dataset.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &DatasetService, name: &str
) -> Result<()> {
client.delete_dataset()
.set_name(name)
.poller().until_done().await?;
Ok(())
}Sourcepub fn import_data(&self) -> ImportData
pub fn import_data(&self) -> ImportData
Imports data into a Dataset.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &DatasetService
) -> Result<()> {
let response = client.import_data()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn export_data(&self) -> ExportData
pub fn export_data(&self) -> ExportData
Exports data from a Dataset.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &DatasetService
) -> Result<()> {
let response = client.export_data()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_dataset_version(&self) -> CreateDatasetVersion
pub fn create_dataset_version(&self) -> CreateDatasetVersion
Create a version from a Dataset.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::model::DatasetVersion;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &DatasetService, parent: &str
) -> Result<()> {
let response = client.create_dataset_version()
.set_parent(parent)
.set_dataset_version(
DatasetVersion::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_dataset_version(&self) -> UpdateDatasetVersion
pub fn update_dataset_version(&self) -> UpdateDatasetVersion
Updates a DatasetVersion.
Example
use google_cloud_wkt::FieldMask;
use google_cloud_aiplatform_v1::model::DatasetVersion;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &DatasetService, name: &str
) -> Result<()> {
let response = client.update_dataset_version()
.set_dataset_version(
DatasetVersion::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_dataset_version(&self) -> DeleteDatasetVersion
pub fn delete_dataset_version(&self) -> DeleteDatasetVersion
Deletes a Dataset version.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &DatasetService, name: &str
) -> Result<()> {
client.delete_dataset_version()
.set_name(name)
.poller().until_done().await?;
Ok(())
}Sourcepub fn get_dataset_version(&self) -> GetDatasetVersion
pub fn get_dataset_version(&self) -> GetDatasetVersion
Gets a Dataset version.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &DatasetService, name: &str
) -> Result<()> {
let response = client.get_dataset_version()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_dataset_versions(&self) -> ListDatasetVersions
pub fn list_dataset_versions(&self) -> ListDatasetVersions
Lists DatasetVersions in a Dataset.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &DatasetService, parent: &str
) -> Result<()> {
let mut list = client.list_dataset_versions()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn restore_dataset_version(&self) -> RestoreDatasetVersion
pub fn restore_dataset_version(&self) -> RestoreDatasetVersion
Restores a dataset version.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &DatasetService
) -> Result<()> {
let response = client.restore_dataset_version()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_data_items(&self) -> ListDataItems
pub fn list_data_items(&self) -> ListDataItems
Lists DataItems in a Dataset.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &DatasetService, parent: &str
) -> Result<()> {
let mut list = client.list_data_items()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn search_data_items(&self) -> SearchDataItems
pub fn search_data_items(&self) -> SearchDataItems
Searches DataItems in a Dataset.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &DatasetService
) -> Result<()> {
let mut list = client.search_data_items()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn list_saved_queries(&self) -> ListSavedQueries
pub fn list_saved_queries(&self) -> ListSavedQueries
Lists SavedQueries in a Dataset.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &DatasetService, parent: &str
) -> Result<()> {
let mut list = client.list_saved_queries()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn delete_saved_query(&self) -> DeleteSavedQuery
pub fn delete_saved_query(&self) -> DeleteSavedQuery
Deletes a SavedQuery.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &DatasetService, name: &str
) -> Result<()> {
client.delete_saved_query()
.set_name(name)
.poller().until_done().await?;
Ok(())
}Sourcepub fn get_annotation_spec(&self) -> GetAnnotationSpec
pub fn get_annotation_spec(&self) -> GetAnnotationSpec
Gets an AnnotationSpec.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &DatasetService, name: &str
) -> Result<()> {
let response = client.get_annotation_spec()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_annotations(&self) -> ListAnnotations
pub fn list_annotations(&self) -> ListAnnotations
Lists Annotations belongs to a dataitem.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &DatasetService, parent: &str
) -> Result<()> {
let mut list = client.list_annotations()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn list_locations(&self) -> ListLocations
pub fn list_locations(&self) -> ListLocations
Lists information about the supported locations for this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &DatasetService
) -> Result<()> {
let mut list = client.list_locations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_location(&self) -> GetLocation
pub fn get_location(&self) -> GetLocation
Gets information about a location.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &DatasetService
) -> Result<()> {
let response = client.get_location()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn set_iam_policy(&self) -> SetIamPolicy
pub fn set_iam_policy(&self) -> SetIamPolicy
Sets the access control policy on the specified resource. Replaces any existing policy.
Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED
errors.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &DatasetService
) -> Result<()> {
let response = client.set_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_iam_policy(&self) -> GetIamPolicy
pub fn get_iam_policy(&self) -> GetIamPolicy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &DatasetService
) -> Result<()> {
let response = client.get_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn test_iam_permissions(&self) -> TestIamPermissions
pub fn test_iam_permissions(&self) -> TestIamPermissions
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of
permissions, not a NOT_FOUND error.
Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &DatasetService
) -> Result<()> {
let response = client.test_iam_permissions()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &DatasetService
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &DatasetService
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &DatasetService
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &DatasetService
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn wait_operation(&self) -> WaitOperation
pub fn wait_operation(&self) -> WaitOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &DatasetService
) -> Result<()> {
let response = client.wait_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Trait Implementations
Sourceimpl Clone for DatasetService
impl Clone for DatasetService
Sourcefn clone(&self) -> DatasetService
fn clone(&self) -> DatasetService
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more