pub struct FeatureOnlineStoreAdminService { /* private fields */ }feature-online-store-admin-service only.Expand description
Implements a client for the Vertex AI API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = FeatureOnlineStoreAdminService::builder().build().await?;
let parent = "parent_value";
let mut list = client.list_feature_online_stores()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
The service that handles CRUD and List for resources for FeatureOnlineStore.
Configuration
To configure FeatureOnlineStoreAdminService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://aiplatform.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
FeatureOnlineStoreAdminService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap FeatureOnlineStoreAdminService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl FeatureOnlineStoreAdminService
impl FeatureOnlineStoreAdminService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for FeatureOnlineStoreAdminService.
let client = FeatureOnlineStoreAdminService::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: FeatureOnlineStoreAdminService + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: FeatureOnlineStoreAdminService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn create_feature_online_store(&self) -> CreateFeatureOnlineStore
pub fn create_feature_online_store(&self) -> CreateFeatureOnlineStore
Creates a new FeatureOnlineStore in a given project and location.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::model::FeatureOnlineStore;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureOnlineStoreAdminService, parent: &str
) -> Result<()> {
let response = client.create_feature_online_store()
.set_parent(parent)
.set_feature_online_store(
FeatureOnlineStore::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_feature_online_store(&self) -> GetFeatureOnlineStore
pub fn get_feature_online_store(&self) -> GetFeatureOnlineStore
Gets details of a single FeatureOnlineStore.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureOnlineStoreAdminService, name: &str
) -> Result<()> {
let response = client.get_feature_online_store()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_feature_online_stores(&self) -> ListFeatureOnlineStores
pub fn list_feature_online_stores(&self) -> ListFeatureOnlineStores
Lists FeatureOnlineStores in a given project and location.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureOnlineStoreAdminService, parent: &str
) -> Result<()> {
let mut list = client.list_feature_online_stores()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn update_feature_online_store(&self) -> UpdateFeatureOnlineStore
pub fn update_feature_online_store(&self) -> UpdateFeatureOnlineStore
Updates the parameters of a single FeatureOnlineStore.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_aiplatform_v1::model::FeatureOnlineStore;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureOnlineStoreAdminService, name: &str
) -> Result<()> {
let response = client.update_feature_online_store()
.set_feature_online_store(
FeatureOnlineStore::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_feature_online_store(&self) -> DeleteFeatureOnlineStore
pub fn delete_feature_online_store(&self) -> DeleteFeatureOnlineStore
Deletes a single FeatureOnlineStore. The FeatureOnlineStore must not contain any FeatureViews.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureOnlineStoreAdminService, name: &str
) -> Result<()> {
client.delete_feature_online_store()
.set_name(name)
.poller().until_done().await?;
Ok(())
}Sourcepub fn create_feature_view(&self) -> CreateFeatureView
pub fn create_feature_view(&self) -> CreateFeatureView
Creates a new FeatureView in a given FeatureOnlineStore.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::model::FeatureView;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureOnlineStoreAdminService, parent: &str
) -> Result<()> {
let response = client.create_feature_view()
.set_parent(parent)
.set_feature_view(
FeatureView::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_feature_view(&self) -> GetFeatureView
pub fn get_feature_view(&self) -> GetFeatureView
Gets details of a single FeatureView.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureOnlineStoreAdminService, name: &str
) -> Result<()> {
let response = client.get_feature_view()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_feature_views(&self) -> ListFeatureViews
pub fn list_feature_views(&self) -> ListFeatureViews
Lists FeatureViews in a given FeatureOnlineStore.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureOnlineStoreAdminService, parent: &str
) -> Result<()> {
let mut list = client.list_feature_views()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn update_feature_view(&self) -> UpdateFeatureView
pub fn update_feature_view(&self) -> UpdateFeatureView
Updates the parameters of a single FeatureView.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_aiplatform_v1::model::FeatureView;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureOnlineStoreAdminService, name: &str
) -> Result<()> {
let response = client.update_feature_view()
.set_feature_view(
FeatureView::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_feature_view(&self) -> DeleteFeatureView
pub fn delete_feature_view(&self) -> DeleteFeatureView
Deletes a single FeatureView.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureOnlineStoreAdminService, name: &str
) -> Result<()> {
client.delete_feature_view()
.set_name(name)
.poller().until_done().await?;
Ok(())
}Sourcepub fn sync_feature_view(&self) -> SyncFeatureView
pub fn sync_feature_view(&self) -> SyncFeatureView
Triggers on-demand sync for the FeatureView.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureOnlineStoreAdminService
) -> Result<()> {
let response = client.sync_feature_view()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_feature_view_sync(&self) -> GetFeatureViewSync
pub fn get_feature_view_sync(&self) -> GetFeatureViewSync
Gets details of a single FeatureViewSync.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureOnlineStoreAdminService, name: &str
) -> Result<()> {
let response = client.get_feature_view_sync()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_feature_view_syncs(&self) -> ListFeatureViewSyncs
pub fn list_feature_view_syncs(&self) -> ListFeatureViewSyncs
Lists FeatureViewSyncs in a given FeatureView.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureOnlineStoreAdminService, parent: &str
) -> Result<()> {
let mut list = client.list_feature_view_syncs()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn list_locations(&self) -> ListLocations
pub fn list_locations(&self) -> ListLocations
Lists information about the supported locations for this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureOnlineStoreAdminService
) -> Result<()> {
let mut list = client.list_locations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_location(&self) -> GetLocation
pub fn get_location(&self) -> GetLocation
Gets information about a location.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureOnlineStoreAdminService
) -> Result<()> {
let response = client.get_location()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn set_iam_policy(&self) -> SetIamPolicy
pub fn set_iam_policy(&self) -> SetIamPolicy
Sets the access control policy on the specified resource. Replaces any existing policy.
Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED
errors.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureOnlineStoreAdminService
) -> Result<()> {
let response = client.set_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_iam_policy(&self) -> GetIamPolicy
pub fn get_iam_policy(&self) -> GetIamPolicy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureOnlineStoreAdminService
) -> Result<()> {
let response = client.get_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn test_iam_permissions(&self) -> TestIamPermissions
pub fn test_iam_permissions(&self) -> TestIamPermissions
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of
permissions, not a NOT_FOUND error.
Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureOnlineStoreAdminService
) -> Result<()> {
let response = client.test_iam_permissions()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureOnlineStoreAdminService
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureOnlineStoreAdminService
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureOnlineStoreAdminService
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureOnlineStoreAdminService
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn wait_operation(&self) -> WaitOperation
pub fn wait_operation(&self) -> WaitOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureOnlineStoreAdminService
) -> Result<()> {
let response = client.wait_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Trait Implementations
Sourceimpl Clone for FeatureOnlineStoreAdminService
impl Clone for FeatureOnlineStoreAdminService
Sourcefn clone(&self) -> FeatureOnlineStoreAdminService
fn clone(&self) -> FeatureOnlineStoreAdminService
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more