pub struct FeatureRegistryService { /* private fields */ }feature-registry-service only.Expand description
Implements a client for the Vertex AI API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = FeatureRegistryService::builder().build().await?;
let parent = "parent_value";
let mut list = client.list_feature_groups()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
The service that handles CRUD and List for resources for FeatureRegistry.
Configuration
To configure FeatureRegistryService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://aiplatform.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
FeatureRegistryService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap FeatureRegistryService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl FeatureRegistryService
impl FeatureRegistryService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for FeatureRegistryService.
let client = FeatureRegistryService::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: FeatureRegistryService + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: FeatureRegistryService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn create_feature_group(&self) -> CreateFeatureGroup
pub fn create_feature_group(&self) -> CreateFeatureGroup
Creates a new FeatureGroup in a given project and location.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::model::FeatureGroup;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureRegistryService, parent: &str
) -> Result<()> {
let response = client.create_feature_group()
.set_parent(parent)
.set_feature_group(
FeatureGroup::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_feature_group(&self) -> GetFeatureGroup
pub fn get_feature_group(&self) -> GetFeatureGroup
Gets details of a single FeatureGroup.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureRegistryService, name: &str
) -> Result<()> {
let response = client.get_feature_group()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_feature_groups(&self) -> ListFeatureGroups
pub fn list_feature_groups(&self) -> ListFeatureGroups
Lists FeatureGroups in a given project and location.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureRegistryService, parent: &str
) -> Result<()> {
let mut list = client.list_feature_groups()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn update_feature_group(&self) -> UpdateFeatureGroup
pub fn update_feature_group(&self) -> UpdateFeatureGroup
Updates the parameters of a single FeatureGroup.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_aiplatform_v1::model::FeatureGroup;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureRegistryService, name: &str
) -> Result<()> {
let response = client.update_feature_group()
.set_feature_group(
FeatureGroup::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_feature_group(&self) -> DeleteFeatureGroup
pub fn delete_feature_group(&self) -> DeleteFeatureGroup
Deletes a single FeatureGroup.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureRegistryService, name: &str
) -> Result<()> {
client.delete_feature_group()
.set_name(name)
.poller().until_done().await?;
Ok(())
}Sourcepub fn create_feature(&self) -> CreateFeature
pub fn create_feature(&self) -> CreateFeature
Creates a new Feature in a given FeatureGroup.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::model::Feature;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureRegistryService, parent: &str
) -> Result<()> {
let response = client.create_feature()
.set_parent(parent)
.set_feature_id("feature_id_value")
.set_feature(
Feature::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn batch_create_features(&self) -> BatchCreateFeatures
pub fn batch_create_features(&self) -> BatchCreateFeatures
Creates a batch of Features in a given FeatureGroup.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureRegistryService
) -> Result<()> {
let response = client.batch_create_features()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_feature(&self) -> GetFeature
pub fn get_feature(&self) -> GetFeature
Gets details of a single Feature.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureRegistryService, name: &str
) -> Result<()> {
let response = client.get_feature()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_features(&self) -> ListFeatures
pub fn list_features(&self) -> ListFeatures
Lists Features in a given FeatureGroup.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureRegistryService, parent: &str
) -> Result<()> {
let mut list = client.list_features()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn update_feature(&self) -> UpdateFeature
pub fn update_feature(&self) -> UpdateFeature
Updates the parameters of a single Feature.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_aiplatform_v1::model::Feature;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureRegistryService, name: &str
) -> Result<()> {
let response = client.update_feature()
.set_feature(
Feature::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_feature(&self) -> DeleteFeature
pub fn delete_feature(&self) -> DeleteFeature
Deletes a single Feature.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureRegistryService, name: &str
) -> Result<()> {
client.delete_feature()
.set_name(name)
.poller().until_done().await?;
Ok(())
}Sourcepub fn list_locations(&self) -> ListLocations
pub fn list_locations(&self) -> ListLocations
Lists information about the supported locations for this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureRegistryService
) -> Result<()> {
let mut list = client.list_locations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_location(&self) -> GetLocation
pub fn get_location(&self) -> GetLocation
Gets information about a location.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureRegistryService
) -> Result<()> {
let response = client.get_location()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn set_iam_policy(&self) -> SetIamPolicy
pub fn set_iam_policy(&self) -> SetIamPolicy
Sets the access control policy on the specified resource. Replaces any existing policy.
Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED
errors.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureRegistryService
) -> Result<()> {
let response = client.set_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_iam_policy(&self) -> GetIamPolicy
pub fn get_iam_policy(&self) -> GetIamPolicy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureRegistryService
) -> Result<()> {
let response = client.get_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn test_iam_permissions(&self) -> TestIamPermissions
pub fn test_iam_permissions(&self) -> TestIamPermissions
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of
permissions, not a NOT_FOUND error.
Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureRegistryService
) -> Result<()> {
let response = client.test_iam_permissions()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureRegistryService
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureRegistryService
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureRegistryService
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureRegistryService
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn wait_operation(&self) -> WaitOperation
pub fn wait_operation(&self) -> WaitOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeatureRegistryService
) -> Result<()> {
let response = client.wait_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Trait Implementations
Sourceimpl Clone for FeatureRegistryService
impl Clone for FeatureRegistryService
Sourcefn clone(&self) -> FeatureRegistryService
fn clone(&self) -> FeatureRegistryService
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more