pub struct GenAiCacheService { /* private fields */ }gen-ai-cache-service only.Expand description
Implements a client for the Vertex AI API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = GenAiCacheService::builder().build().await?;
let parent = "parent_value";
let mut list = client.list_cached_contents()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
Service for managing Vertex AI’s CachedContent resource.
Configuration
To configure GenAiCacheService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://aiplatform.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
GenAiCacheService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap GenAiCacheService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl GenAiCacheService
impl GenAiCacheService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for GenAiCacheService.
let client = GenAiCacheService::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: GenAiCacheService + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: GenAiCacheService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn create_cached_content(&self) -> CreateCachedContent
pub fn create_cached_content(&self) -> CreateCachedContent
Creates cached content, this call will initialize the cached content in the data storage, and users need to pay for the cache data storage.
Example
use google_cloud_aiplatform_v1::model::CachedContent;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &GenAiCacheService, parent: &str
) -> Result<()> {
let response = client.create_cached_content()
.set_parent(parent)
.set_cached_content(
CachedContent::new()/* set fields */
)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_cached_content(&self) -> GetCachedContent
pub fn get_cached_content(&self) -> GetCachedContent
Gets cached content configurations
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &GenAiCacheService, name: &str
) -> Result<()> {
let response = client.get_cached_content()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_cached_content(&self) -> UpdateCachedContent
pub fn update_cached_content(&self) -> UpdateCachedContent
Updates cached content configurations
Example
use google_cloud_wkt::FieldMask;
use google_cloud_aiplatform_v1::model::CachedContent;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &GenAiCacheService, name: &str
) -> Result<()> {
let response = client.update_cached_content()
.set_cached_content(
CachedContent::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_cached_content(&self) -> DeleteCachedContent
pub fn delete_cached_content(&self) -> DeleteCachedContent
Deletes cached content
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &GenAiCacheService, name: &str
) -> Result<()> {
client.delete_cached_content()
.set_name(name)
.send().await?;
Ok(())
}Sourcepub fn list_cached_contents(&self) -> ListCachedContents
pub fn list_cached_contents(&self) -> ListCachedContents
Lists cached contents in a project
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &GenAiCacheService, parent: &str
) -> Result<()> {
let mut list = client.list_cached_contents()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn list_locations(&self) -> ListLocations
pub fn list_locations(&self) -> ListLocations
Lists information about the supported locations for this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &GenAiCacheService
) -> Result<()> {
let mut list = client.list_locations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_location(&self) -> GetLocation
pub fn get_location(&self) -> GetLocation
Gets information about a location.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &GenAiCacheService
) -> Result<()> {
let response = client.get_location()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn set_iam_policy(&self) -> SetIamPolicy
pub fn set_iam_policy(&self) -> SetIamPolicy
Sets the access control policy on the specified resource. Replaces any existing policy.
Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED
errors.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &GenAiCacheService
) -> Result<()> {
let response = client.set_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_iam_policy(&self) -> GetIamPolicy
pub fn get_iam_policy(&self) -> GetIamPolicy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &GenAiCacheService
) -> Result<()> {
let response = client.get_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn test_iam_permissions(&self) -> TestIamPermissions
pub fn test_iam_permissions(&self) -> TestIamPermissions
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of
permissions, not a NOT_FOUND error.
Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &GenAiCacheService
) -> Result<()> {
let response = client.test_iam_permissions()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &GenAiCacheService
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &GenAiCacheService
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &GenAiCacheService
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &GenAiCacheService
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn wait_operation(&self) -> WaitOperation
pub fn wait_operation(&self) -> WaitOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &GenAiCacheService
) -> Result<()> {
let response = client.wait_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Trait Implementations
Sourceimpl Clone for GenAiCacheService
impl Clone for GenAiCacheService
Sourcefn clone(&self) -> GenAiCacheService
fn clone(&self) -> GenAiCacheService
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more