MetadataService

Struct MetadataService 

pub struct MetadataService { /* private fields */ }
Available on crate feature metadata-service only.
Implements a client for the Vertex AI API.

Example

use google_cloud_gax::paginator::ItemPaginator as _;
    let client = MetadataService::builder().build().await?;
    let parent = "parent_value";
    let mut list = client.list_metadata_stores()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }

Service Description

Service for reading and writing metadata entries.

Configuration

To configure MetadataService use the with_* methods in the type returned by builder(). The default configuration should work for most applications. Common configuration changes include

  • with_endpoint(): by default this client uses the global default endpoint (https://aiplatform.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default.
  • with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.

Pooling and Cloning

MetadataService holds a connection pool internally, it is advised to create one and reuse it. You do not need to wrap MetadataService in an Rc or Arc to reuse it, because it already uses an Arc internally.

Implementations

Source

impl MetadataService

pub fn builder() -> ClientBuilder

Returns a builder for MetadataService.

let client = MetadataService::builder().build().await?;
pub fn from_stub<T>(stub: T) -> Self
where T: MetadataService + 'static,

Creates a new client from the provided stub.

The most common case for calling this function is in tests mocking the client’s behavior.

pub fn create_metadata_store(&self) -> CreateMetadataStore

Initializes a MetadataStore, including allocation of resources.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::model::MetadataStore;
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService, parent: &str
) -> Result<()> {
    let response = client.create_metadata_store()
        .set_parent(parent)
        .set_metadata_store(
            MetadataStore::new()/* set fields */
        )
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_metadata_store(&self) -> GetMetadataStore

Retrieves a specific MetadataStore.

Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService, name: &str
) -> Result<()> {
    let response = client.get_metadata_store()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_metadata_stores(&self) -> ListMetadataStores

Lists MetadataStores for a Location.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService, parent: &str
) -> Result<()> {
    let mut list = client.list_metadata_stores()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn delete_metadata_store(&self) -> DeleteMetadataStore

Deletes a single MetadataStore and all its child resources (Artifacts, Executions, and Contexts).

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService, name: &str
) -> Result<()> {
    client.delete_metadata_store()
        .set_name(name)
        .poller().until_done().await?;
    Ok(())
}
pub fn create_artifact(&self) -> CreateArtifact

Creates an Artifact associated with a MetadataStore.

Example
use google_cloud_aiplatform_v1::model::Artifact;
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService, parent: &str
) -> Result<()> {
    let response = client.create_artifact()
        .set_parent(parent)
        .set_artifact_id("artifact_id_value")
        .set_artifact(
            Artifact::new()/* set fields */
        )
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_artifact(&self) -> GetArtifact

Retrieves a specific Artifact.

Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService, name: &str
) -> Result<()> {
    let response = client.get_artifact()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_artifacts(&self) -> ListArtifacts

Lists Artifacts in the MetadataStore.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService, parent: &str
) -> Result<()> {
    let mut list = client.list_artifacts()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn update_artifact(&self) -> UpdateArtifact

Updates a stored Artifact.

Example
use google_cloud_wkt::FieldMask;
use google_cloud_aiplatform_v1::model::Artifact;
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService, name: &str
) -> Result<()> {
    let response = client.update_artifact()
        .set_artifact(
            Artifact::new().set_name(name)/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_artifact(&self) -> DeleteArtifact

Deletes an Artifact.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService, name: &str
) -> Result<()> {
    client.delete_artifact()
        .set_name(name)
        .poller().until_done().await?;
    Ok(())
}
pub fn purge_artifacts(&self) -> PurgeArtifacts

Purges Artifacts.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService
) -> Result<()> {
    let response = client.purge_artifacts()
        /* set fields */
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_context(&self) -> CreateContext

Creates a Context associated with a MetadataStore.

Example
use google_cloud_aiplatform_v1::model::Context;
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService, parent: &str
) -> Result<()> {
    let response = client.create_context()
        .set_parent(parent)
        .set_context_id("context_id_value")
        .set_context(
            Context::new()/* set fields */
        )
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_context(&self) -> GetContext

Retrieves a specific Context.

Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService, name: &str
) -> Result<()> {
    let response = client.get_context()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_contexts(&self) -> ListContexts

Lists Contexts on the MetadataStore.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService, parent: &str
) -> Result<()> {
    let mut list = client.list_contexts()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn update_context(&self) -> UpdateContext

Updates a stored Context.

Example
use google_cloud_wkt::FieldMask;
use google_cloud_aiplatform_v1::model::Context;
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService, name: &str
) -> Result<()> {
    let response = client.update_context()
        .set_context(
            Context::new().set_name(name)/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_context(&self) -> DeleteContext

Deletes a stored Context.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService, name: &str
) -> Result<()> {
    client.delete_context()
        .set_name(name)
        .poller().until_done().await?;
    Ok(())
}
pub fn purge_contexts(&self) -> PurgeContexts

Purges Contexts.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService
) -> Result<()> {
    let response = client.purge_contexts()
        /* set fields */
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn add_context_artifacts_and_executions( &self, ) -> AddContextArtifactsAndExecutions

Adds a set of Artifacts and Executions to a Context. If any of the Artifacts or Executions have already been added to a Context, they are simply skipped.

Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService
) -> Result<()> {
    let response = client.add_context_artifacts_and_executions()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn add_context_children(&self) -> AddContextChildren

Adds a set of Contexts as children to a parent Context. If any of the child Contexts have already been added to the parent Context, they are simply skipped. If this call would create a cycle or cause any Context to have more than 10 parents, the request will fail with an INVALID_ARGUMENT error.

Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService
) -> Result<()> {
    let response = client.add_context_children()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn remove_context_children(&self) -> RemoveContextChildren

Remove a set of children contexts from a parent Context. If any of the child Contexts were NOT added to the parent Context, they are simply skipped.

Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService
) -> Result<()> {
    let response = client.remove_context_children()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn query_context_lineage_subgraph(&self) -> QueryContextLineageSubgraph

Retrieves Artifacts and Executions within the specified Context, connected by Event edges and returned as a LineageSubgraph.

Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService
) -> Result<()> {
    let response = client.query_context_lineage_subgraph()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_execution(&self) -> CreateExecution

Creates an Execution associated with a MetadataStore.

Example
use google_cloud_aiplatform_v1::model::Execution;
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService, parent: &str
) -> Result<()> {
    let response = client.create_execution()
        .set_parent(parent)
        .set_execution_id("execution_id_value")
        .set_execution(
            Execution::new()/* set fields */
        )
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_execution(&self) -> GetExecution

Retrieves a specific Execution.

Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService, name: &str
) -> Result<()> {
    let response = client.get_execution()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_executions(&self) -> ListExecutions

Lists Executions in the MetadataStore.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService, parent: &str
) -> Result<()> {
    let mut list = client.list_executions()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn update_execution(&self) -> UpdateExecution

Updates a stored Execution.

Example
use google_cloud_wkt::FieldMask;
use google_cloud_aiplatform_v1::model::Execution;
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService, name: &str
) -> Result<()> {
    let response = client.update_execution()
        .set_execution(
            Execution::new().set_name(name)/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_execution(&self) -> DeleteExecution

Deletes an Execution.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService, name: &str
) -> Result<()> {
    client.delete_execution()
        .set_name(name)
        .poller().until_done().await?;
    Ok(())
}
pub fn purge_executions(&self) -> PurgeExecutions

Purges Executions.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService
) -> Result<()> {
    let response = client.purge_executions()
        /* set fields */
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn add_execution_events(&self) -> AddExecutionEvents

Adds Events to the specified Execution. An Event indicates whether an Artifact was used as an input or output for an Execution. If an Event already exists between the Execution and the Artifact, the Event is skipped.

Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService
) -> Result<()> {
    let response = client.add_execution_events()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn query_execution_inputs_and_outputs( &self, ) -> QueryExecutionInputsAndOutputs

Obtains the set of input and output Artifacts for this Execution, in the form of LineageSubgraph that also contains the Execution and connecting Events.

Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService
) -> Result<()> {
    let response = client.query_execution_inputs_and_outputs()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_metadata_schema(&self) -> CreateMetadataSchema

Creates a MetadataSchema.

Example
use google_cloud_aiplatform_v1::model::MetadataSchema;
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService, parent: &str
) -> Result<()> {
    let response = client.create_metadata_schema()
        .set_parent(parent)
        .set_metadata_schema(
            MetadataSchema::new()/* set fields */
        )
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_metadata_schema(&self) -> GetMetadataSchema

Retrieves a specific MetadataSchema.

Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService, name: &str
) -> Result<()> {
    let response = client.get_metadata_schema()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_metadata_schemas(&self) -> ListMetadataSchemas

Lists MetadataSchemas.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService, parent: &str
) -> Result<()> {
    let mut list = client.list_metadata_schemas()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn query_artifact_lineage_subgraph(&self) -> QueryArtifactLineageSubgraph

Retrieves lineage of an Artifact represented through Artifacts and Executions connected by Event edges and returned as a LineageSubgraph.

Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService
) -> Result<()> {
    let response = client.query_artifact_lineage_subgraph()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_locations(&self) -> ListLocations

Lists information about the supported locations for this service.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService
) -> Result<()> {
    let mut list = client.list_locations()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_location(&self) -> GetLocation

Gets information about a location.

Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService
) -> Result<()> {
    let response = client.get_location()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn set_iam_policy(&self) -> SetIamPolicy

Sets the access control policy on the specified resource. Replaces any existing policy.

Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED errors.

Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService
) -> Result<()> {
    let response = client.set_iam_policy()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_iam_policy(&self) -> GetIamPolicy

Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.

Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService
) -> Result<()> {
    let response = client.get_iam_policy()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn test_iam_permissions(&self) -> TestIamPermissions

Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error.

Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.

Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService
) -> Result<()> {
    let response = client.test_iam_permissions()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_operations(&self) -> ListOperations

Provides the Operations service functionality in this service.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService
) -> Result<()> {
    let mut list = client.list_operations()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_operation(&self) -> GetOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService
) -> Result<()> {
    let response = client.get_operation()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_operation(&self) -> DeleteOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService
) -> Result<()> {
    client.delete_operation()
        /* set fields */
        .send().await?;
    Ok(())
}
pub fn cancel_operation(&self) -> CancelOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService
) -> Result<()> {
    client.cancel_operation()
        /* set fields */
        .send().await?;
    Ok(())
}
pub fn wait_operation(&self) -> WaitOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &MetadataService
) -> Result<()> {
    let response = client.wait_operation()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}