pub struct NotebookService { /* private fields */ }notebook-service only.Expand description
Implements a client for the Vertex AI API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = NotebookService::builder().build().await?;
let parent = "parent_value";
let mut list = client.list_notebook_runtime_templates()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
The interface for Vertex Notebook service (a.k.a. Colab on Workbench).
Configuration
To configure NotebookService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://aiplatform.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
NotebookService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap NotebookService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl NotebookService
impl NotebookService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for NotebookService.
let client = NotebookService::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: NotebookService + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: NotebookService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn create_notebook_runtime_template(&self) -> CreateNotebookRuntimeTemplate
pub fn create_notebook_runtime_template(&self) -> CreateNotebookRuntimeTemplate
Creates a NotebookRuntimeTemplate.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::model::NotebookRuntimeTemplate;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &NotebookService, parent: &str
) -> Result<()> {
let response = client.create_notebook_runtime_template()
.set_parent(parent)
.set_notebook_runtime_template(
NotebookRuntimeTemplate::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_notebook_runtime_template(&self) -> GetNotebookRuntimeTemplate
pub fn get_notebook_runtime_template(&self) -> GetNotebookRuntimeTemplate
Gets a NotebookRuntimeTemplate.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &NotebookService, name: &str
) -> Result<()> {
let response = client.get_notebook_runtime_template()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_notebook_runtime_templates(&self) -> ListNotebookRuntimeTemplates
pub fn list_notebook_runtime_templates(&self) -> ListNotebookRuntimeTemplates
Lists NotebookRuntimeTemplates in a Location.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &NotebookService, parent: &str
) -> Result<()> {
let mut list = client.list_notebook_runtime_templates()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn delete_notebook_runtime_template(&self) -> DeleteNotebookRuntimeTemplate
pub fn delete_notebook_runtime_template(&self) -> DeleteNotebookRuntimeTemplate
Deletes a NotebookRuntimeTemplate.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &NotebookService, name: &str
) -> Result<()> {
client.delete_notebook_runtime_template()
.set_name(name)
.poller().until_done().await?;
Ok(())
}Sourcepub fn update_notebook_runtime_template(&self) -> UpdateNotebookRuntimeTemplate
pub fn update_notebook_runtime_template(&self) -> UpdateNotebookRuntimeTemplate
Updates a NotebookRuntimeTemplate.
Example
use google_cloud_wkt::FieldMask;
use google_cloud_aiplatform_v1::model::NotebookRuntimeTemplate;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &NotebookService, name: &str
) -> Result<()> {
let response = client.update_notebook_runtime_template()
.set_notebook_runtime_template(
NotebookRuntimeTemplate::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn assign_notebook_runtime(&self) -> AssignNotebookRuntime
pub fn assign_notebook_runtime(&self) -> AssignNotebookRuntime
Assigns a NotebookRuntime to a user for a particular Notebook file. This method will either returns an existing assignment or generates a new one.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &NotebookService
) -> Result<()> {
let response = client.assign_notebook_runtime()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_notebook_runtime(&self) -> GetNotebookRuntime
pub fn get_notebook_runtime(&self) -> GetNotebookRuntime
Gets a NotebookRuntime.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &NotebookService, name: &str
) -> Result<()> {
let response = client.get_notebook_runtime()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_notebook_runtimes(&self) -> ListNotebookRuntimes
pub fn list_notebook_runtimes(&self) -> ListNotebookRuntimes
Lists NotebookRuntimes in a Location.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &NotebookService, parent: &str
) -> Result<()> {
let mut list = client.list_notebook_runtimes()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn delete_notebook_runtime(&self) -> DeleteNotebookRuntime
pub fn delete_notebook_runtime(&self) -> DeleteNotebookRuntime
Deletes a NotebookRuntime.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &NotebookService, name: &str
) -> Result<()> {
client.delete_notebook_runtime()
.set_name(name)
.poller().until_done().await?;
Ok(())
}Sourcepub fn upgrade_notebook_runtime(&self) -> UpgradeNotebookRuntime
pub fn upgrade_notebook_runtime(&self) -> UpgradeNotebookRuntime
Upgrades a NotebookRuntime.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &NotebookService
) -> Result<()> {
let response = client.upgrade_notebook_runtime()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn start_notebook_runtime(&self) -> StartNotebookRuntime
pub fn start_notebook_runtime(&self) -> StartNotebookRuntime
Starts a NotebookRuntime.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &NotebookService
) -> Result<()> {
let response = client.start_notebook_runtime()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn stop_notebook_runtime(&self) -> StopNotebookRuntime
pub fn stop_notebook_runtime(&self) -> StopNotebookRuntime
Stops a NotebookRuntime.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &NotebookService
) -> Result<()> {
let response = client.stop_notebook_runtime()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_notebook_execution_job(&self) -> CreateNotebookExecutionJob
pub fn create_notebook_execution_job(&self) -> CreateNotebookExecutionJob
Creates a NotebookExecutionJob.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::model::NotebookExecutionJob;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &NotebookService, parent: &str
) -> Result<()> {
let response = client.create_notebook_execution_job()
.set_parent(parent)
.set_notebook_execution_job(
NotebookExecutionJob::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_notebook_execution_job(&self) -> GetNotebookExecutionJob
pub fn get_notebook_execution_job(&self) -> GetNotebookExecutionJob
Gets a NotebookExecutionJob.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &NotebookService, name: &str
) -> Result<()> {
let response = client.get_notebook_execution_job()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_notebook_execution_jobs(&self) -> ListNotebookExecutionJobs
pub fn list_notebook_execution_jobs(&self) -> ListNotebookExecutionJobs
Lists NotebookExecutionJobs in a Location.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &NotebookService, parent: &str
) -> Result<()> {
let mut list = client.list_notebook_execution_jobs()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn delete_notebook_execution_job(&self) -> DeleteNotebookExecutionJob
pub fn delete_notebook_execution_job(&self) -> DeleteNotebookExecutionJob
Deletes a NotebookExecutionJob.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &NotebookService, name: &str
) -> Result<()> {
client.delete_notebook_execution_job()
.set_name(name)
.poller().until_done().await?;
Ok(())
}Sourcepub fn list_locations(&self) -> ListLocations
pub fn list_locations(&self) -> ListLocations
Lists information about the supported locations for this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &NotebookService
) -> Result<()> {
let mut list = client.list_locations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_location(&self) -> GetLocation
pub fn get_location(&self) -> GetLocation
Gets information about a location.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &NotebookService
) -> Result<()> {
let response = client.get_location()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn set_iam_policy(&self) -> SetIamPolicy
pub fn set_iam_policy(&self) -> SetIamPolicy
Sets the access control policy on the specified resource. Replaces any existing policy.
Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED
errors.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &NotebookService
) -> Result<()> {
let response = client.set_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_iam_policy(&self) -> GetIamPolicy
pub fn get_iam_policy(&self) -> GetIamPolicy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &NotebookService
) -> Result<()> {
let response = client.get_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn test_iam_permissions(&self) -> TestIamPermissions
pub fn test_iam_permissions(&self) -> TestIamPermissions
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of
permissions, not a NOT_FOUND error.
Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &NotebookService
) -> Result<()> {
let response = client.test_iam_permissions()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &NotebookService
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &NotebookService
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &NotebookService
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &NotebookService
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn wait_operation(&self) -> WaitOperation
pub fn wait_operation(&self) -> WaitOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &NotebookService
) -> Result<()> {
let response = client.wait_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Trait Implementations
Sourceimpl Clone for NotebookService
impl Clone for NotebookService
Sourcefn clone(&self) -> NotebookService
fn clone(&self) -> NotebookService
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more