PipelineService

Struct PipelineService 

pub struct PipelineService { /* private fields */ }
Available on crate feature pipeline-service only.
Implements a client for the Vertex AI API.

Example

use google_cloud_gax::paginator::ItemPaginator as _;
async fn sample(
   parent: &str,
) -> anyhow::Result<()> {
    let client = PipelineService::builder().build().await?;
    let mut list = client.list_training_pipelines()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}

Service Description

A service for creating and managing Vertex AI’s pipelines. This includes both TrainingPipeline resources (used for AutoML and custom training) and PipelineJob resources (used for Vertex AI Pipelines).

Configuration

To configure PipelineService use the with_* methods in the type returned by builder(). The default configuration should work for most applications. Common configuration changes include

Pooling and Cloning

PipelineService holds a connection pool internally, it is advised to create one and reuse it. You do not need to wrap PipelineService in an Rc or Arc to reuse it, because it already uses an Arc internally.

Implementations

Source

impl PipelineService

pub fn builder() -> ClientBuilder

Returns a builder for PipelineService.

let client = PipelineService::builder().build().await?;
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Self
where T: PipelineService + 'static,

Creates a new client from the provided stub.

The most common case for calling this function is in tests mocking the client’s behavior.

pub fn create_training_pipeline(&self) -> CreateTrainingPipeline

Creates a TrainingPipeline. A created TrainingPipeline right away will be attempted to be run.

Example
use google_cloud_aiplatform_v1::model::TrainingPipeline;
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &PipelineService, parent: &str
) -> Result<()> {
    let response = client.create_training_pipeline()
        .set_parent(parent)
        .set_training_pipeline(
            TrainingPipeline::new()/* set fields */
        )
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_training_pipeline(&self) -> GetTrainingPipeline

Gets a TrainingPipeline.

Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &PipelineService, project_id: &str, location_id: &str, training_pipeline_id: &str
) -> Result<()> {
    let response = client.get_training_pipeline()
        .set_name(format!("projects/{project_id}/locations/{location_id}/trainingPipelines/{training_pipeline_id}"))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_training_pipelines(&self) -> ListTrainingPipelines

Lists TrainingPipelines in a Location.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &PipelineService, parent: &str
) -> Result<()> {
    let mut list = client.list_training_pipelines()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn delete_training_pipeline(&self) -> DeleteTrainingPipeline

Deletes a TrainingPipeline.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &PipelineService, project_id: &str, location_id: &str, training_pipeline_id: &str
) -> Result<()> {
    client.delete_training_pipeline()
        .set_name(format!("projects/{project_id}/locations/{location_id}/trainingPipelines/{training_pipeline_id}"))
        .poller().until_done().await?;
    Ok(())
}
pub fn cancel_training_pipeline(&self) -> CancelTrainingPipeline

Cancels a TrainingPipeline. Starts asynchronous cancellation on the TrainingPipeline. The server makes a best effort to cancel the pipeline, but success is not guaranteed. Clients can use PipelineService.GetTrainingPipeline or other methods to check whether the cancellation succeeded or whether the pipeline completed despite cancellation. On successful cancellation, the TrainingPipeline is not deleted; instead it becomes a pipeline with a TrainingPipeline.error value with a google.rpc.Status.code of 1, corresponding to Code.CANCELLED, and TrainingPipeline.state is set to CANCELLED.

Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &PipelineService
) -> Result<()> {
    client.cancel_training_pipeline()
        /* set fields */
        .send().await?;
    Ok(())
}
pub fn create_pipeline_job(&self) -> CreatePipelineJob

Creates a PipelineJob. A PipelineJob will run immediately when created.

Example
use google_cloud_aiplatform_v1::model::PipelineJob;
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &PipelineService, parent: &str
) -> Result<()> {
    let response = client.create_pipeline_job()
        .set_parent(parent)
        .set_pipeline_job(
            PipelineJob::new()/* set fields */
        )
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_pipeline_job(&self) -> GetPipelineJob

Gets a PipelineJob.

Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &PipelineService, project_id: &str, location_id: &str, pipeline_job_id: &str
) -> Result<()> {
    let response = client.get_pipeline_job()
        .set_name(format!("projects/{project_id}/locations/{location_id}/pipelineJobs/{pipeline_job_id}"))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_pipeline_jobs(&self) -> ListPipelineJobs

Lists PipelineJobs in a Location.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &PipelineService, parent: &str
) -> Result<()> {
    let mut list = client.list_pipeline_jobs()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn delete_pipeline_job(&self) -> DeletePipelineJob

Deletes a PipelineJob.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &PipelineService, project_id: &str, location_id: &str, pipeline_job_id: &str
) -> Result<()> {
    client.delete_pipeline_job()
        .set_name(format!("projects/{project_id}/locations/{location_id}/pipelineJobs/{pipeline_job_id}"))
        .poller().until_done().await?;
    Ok(())
}
pub fn batch_delete_pipeline_jobs(&self) -> BatchDeletePipelineJobs

Batch deletes PipelineJobs The Operation is atomic. If it fails, none of the PipelineJobs are deleted. If it succeeds, all of the PipelineJobs are deleted.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &PipelineService
) -> Result<()> {
    let response = client.batch_delete_pipeline_jobs()
        /* set fields */
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn cancel_pipeline_job(&self) -> CancelPipelineJob

Cancels a PipelineJob. Starts asynchronous cancellation on the PipelineJob. The server makes a best effort to cancel the pipeline, but success is not guaranteed. Clients can use PipelineService.GetPipelineJob or other methods to check whether the cancellation succeeded or whether the pipeline completed despite cancellation. On successful cancellation, the PipelineJob is not deleted; instead it becomes a pipeline with a PipelineJob.error value with a google.rpc.Status.code of 1, corresponding to Code.CANCELLED, and PipelineJob.state is set to CANCELLED.

Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &PipelineService
) -> Result<()> {
    client.cancel_pipeline_job()
        /* set fields */
        .send().await?;
    Ok(())
}
pub fn batch_cancel_pipeline_jobs(&self) -> BatchCancelPipelineJobs

Batch cancel PipelineJobs. Firstly the server will check if all the jobs are in non-terminal states, and skip the jobs that are already terminated. If the operation failed, none of the pipeline jobs are cancelled. The server will poll the states of all the pipeline jobs periodically to check the cancellation status. This operation will return an LRO.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &PipelineService
) -> Result<()> {
    let response = client.batch_cancel_pipeline_jobs()
        /* set fields */
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_locations(&self) -> ListLocations

Lists information about the supported locations for this service.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &PipelineService
) -> Result<()> {
    let mut list = client.list_locations()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_location(&self) -> GetLocation

Gets information about a location.

Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &PipelineService
) -> Result<()> {
    let response = client.get_location()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn set_iam_policy(&self) -> SetIamPolicy

Sets the access control policy on the specified resource. Replaces any existing policy.

Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED errors.

Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &PipelineService
) -> Result<()> {
    let response = client.set_iam_policy()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_iam_policy(&self) -> GetIamPolicy

Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.

Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &PipelineService
) -> Result<()> {
    let response = client.get_iam_policy()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn test_iam_permissions(&self) -> TestIamPermissions

Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error.

Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.

Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &PipelineService
) -> Result<()> {
    let response = client.test_iam_permissions()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_operations(&self) -> ListOperations

Provides the Operations service functionality in this service.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &PipelineService
) -> Result<()> {
    let mut list = client.list_operations()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_operation(&self) -> GetOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &PipelineService
) -> Result<()> {
    let response = client.get_operation()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_operation(&self) -> DeleteOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &PipelineService
) -> Result<()> {
    client.delete_operation()
        /* set fields */
        .send().await?;
    Ok(())
}
pub fn cancel_operation(&self) -> CancelOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &PipelineService
) -> Result<()> {
    client.cancel_operation()
        /* set fields */
        .send().await?;
    Ok(())
}
pub fn wait_operation(&self) -> WaitOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
   client: &PipelineService
) -> Result<()> {
    let response = client.wait_operation()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}