pub struct PredictionService { /* private fields */ }prediction-service only.Expand description
Implements a client for the Vertex AI API.
Example
let client = PredictionService::builder().build().await?;
let response = client.predict()
/* set fields */
.send().await?;
println!("response {:?}", response);Service Description
A service for online predictions and explanations.
Configuration
To configure PredictionService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://aiplatform.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
PredictionService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap PredictionService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl PredictionService
impl PredictionService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for PredictionService.
let client = PredictionService::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: PredictionService + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: PredictionService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn predict(&self) -> Predict
pub fn predict(&self) -> Predict
Perform an online prediction.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &PredictionService
) -> Result<()> {
let response = client.predict()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn raw_predict(&self) -> RawPredict
pub fn raw_predict(&self) -> RawPredict
Perform an online prediction with an arbitrary HTTP payload.
The response includes the following HTTP headers:
-
X-Vertex-AI-Endpoint-Id: ID of the Endpoint that served this prediction. -
X-Vertex-AI-Deployed-Model-Id: ID of the Endpoint’s DeployedModel that served this prediction.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &PredictionService
) -> Result<()> {
let response = client.raw_predict()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn direct_predict(&self) -> DirectPredict
pub fn direct_predict(&self) -> DirectPredict
Perform an unary online prediction request to a gRPC model server for Vertex first-party products and frameworks.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &PredictionService
) -> Result<()> {
let response = client.direct_predict()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn direct_raw_predict(&self) -> DirectRawPredict
pub fn direct_raw_predict(&self) -> DirectRawPredict
Perform an unary online prediction request to a gRPC model server for custom containers.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &PredictionService
) -> Result<()> {
let response = client.direct_raw_predict()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn explain(&self) -> Explain
pub fn explain(&self) -> Explain
Perform an online explanation.
If deployed_model_id is specified, the corresponding DeployModel must have explanation_spec populated. If deployed_model_id is not specified, all DeployedModels must have explanation_spec populated.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &PredictionService
) -> Result<()> {
let response = client.explain()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn generate_content(&self) -> GenerateContent
pub fn generate_content(&self) -> GenerateContent
Generate content with multimodal inputs.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &PredictionService
) -> Result<()> {
let response = client.generate_content()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn embed_content(&self) -> EmbedContent
pub fn embed_content(&self) -> EmbedContent
Embed content with multimodal inputs.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &PredictionService
) -> Result<()> {
let response = client.embed_content()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_locations(&self) -> ListLocations
pub fn list_locations(&self) -> ListLocations
Lists information about the supported locations for this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &PredictionService
) -> Result<()> {
let mut list = client.list_locations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_location(&self) -> GetLocation
pub fn get_location(&self) -> GetLocation
Gets information about a location.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &PredictionService
) -> Result<()> {
let response = client.get_location()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn set_iam_policy(&self) -> SetIamPolicy
pub fn set_iam_policy(&self) -> SetIamPolicy
Sets the access control policy on the specified resource. Replaces any existing policy.
Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED
errors.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &PredictionService
) -> Result<()> {
let response = client.set_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_iam_policy(&self) -> GetIamPolicy
pub fn get_iam_policy(&self) -> GetIamPolicy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &PredictionService
) -> Result<()> {
let response = client.get_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn test_iam_permissions(&self) -> TestIamPermissions
pub fn test_iam_permissions(&self) -> TestIamPermissions
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of
permissions, not a NOT_FOUND error.
Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &PredictionService
) -> Result<()> {
let response = client.test_iam_permissions()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &PredictionService
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &PredictionService
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &PredictionService
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &PredictionService
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn wait_operation(&self) -> WaitOperation
pub fn wait_operation(&self) -> WaitOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &PredictionService
) -> Result<()> {
let response = client.wait_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Trait Implementations
Sourceimpl Clone for PredictionService
impl Clone for PredictionService
Sourcefn clone(&self) -> PredictionService
fn clone(&self) -> PredictionService
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more