pub struct TensorboardService { /* private fields */ }tensorboard-service only.Expand description
Implements a client for the Vertex AI API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = TensorboardService::builder().build().await?;
let parent = "parent_value";
let mut list = client.list_tensorboards()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
TensorboardService
Configuration
To configure TensorboardService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://aiplatform.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
TensorboardService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap TensorboardService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl TensorboardService
impl TensorboardService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for TensorboardService.
let client = TensorboardService::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: TensorboardService + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: TensorboardService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn create_tensorboard(&self) -> CreateTensorboard
pub fn create_tensorboard(&self) -> CreateTensorboard
Creates a Tensorboard.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::model::Tensorboard;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService, parent: &str
) -> Result<()> {
let response = client.create_tensorboard()
.set_parent(parent)
.set_tensorboard(
Tensorboard::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_tensorboard(&self) -> GetTensorboard
pub fn get_tensorboard(&self) -> GetTensorboard
Gets a Tensorboard.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService, name: &str
) -> Result<()> {
let response = client.get_tensorboard()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_tensorboard(&self) -> UpdateTensorboard
pub fn update_tensorboard(&self) -> UpdateTensorboard
Updates a Tensorboard.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_aiplatform_v1::model::Tensorboard;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService, name: &str
) -> Result<()> {
let response = client.update_tensorboard()
.set_tensorboard(
Tensorboard::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_tensorboards(&self) -> ListTensorboards
pub fn list_tensorboards(&self) -> ListTensorboards
Lists Tensorboards in a Location.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService, parent: &str
) -> Result<()> {
let mut list = client.list_tensorboards()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn delete_tensorboard(&self) -> DeleteTensorboard
pub fn delete_tensorboard(&self) -> DeleteTensorboard
Deletes a Tensorboard.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService, name: &str
) -> Result<()> {
client.delete_tensorboard()
.set_name(name)
.poller().until_done().await?;
Ok(())
}Sourcepub fn read_tensorboard_usage(&self) -> ReadTensorboardUsage
pub fn read_tensorboard_usage(&self) -> ReadTensorboardUsage
Returns a list of monthly active users for a given TensorBoard instance.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService
) -> Result<()> {
let response = client.read_tensorboard_usage()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn read_tensorboard_size(&self) -> ReadTensorboardSize
pub fn read_tensorboard_size(&self) -> ReadTensorboardSize
Returns the storage size for a given TensorBoard instance.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService
) -> Result<()> {
let response = client.read_tensorboard_size()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_tensorboard_experiment(&self) -> CreateTensorboardExperiment
pub fn create_tensorboard_experiment(&self) -> CreateTensorboardExperiment
Creates a TensorboardExperiment.
Example
use google_cloud_aiplatform_v1::model::TensorboardExperiment;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService, parent: &str
) -> Result<()> {
let response = client.create_tensorboard_experiment()
.set_parent(parent)
.set_tensorboard_experiment(
TensorboardExperiment::new()/* set fields */
)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_tensorboard_experiment(&self) -> GetTensorboardExperiment
pub fn get_tensorboard_experiment(&self) -> GetTensorboardExperiment
Gets a TensorboardExperiment.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService, name: &str
) -> Result<()> {
let response = client.get_tensorboard_experiment()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_tensorboard_experiment(&self) -> UpdateTensorboardExperiment
pub fn update_tensorboard_experiment(&self) -> UpdateTensorboardExperiment
Updates a TensorboardExperiment.
Example
use google_cloud_wkt::FieldMask;
use google_cloud_aiplatform_v1::model::TensorboardExperiment;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService, name: &str
) -> Result<()> {
let response = client.update_tensorboard_experiment()
.set_tensorboard_experiment(
TensorboardExperiment::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_tensorboard_experiments(&self) -> ListTensorboardExperiments
pub fn list_tensorboard_experiments(&self) -> ListTensorboardExperiments
Lists TensorboardExperiments in a Location.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService, parent: &str
) -> Result<()> {
let mut list = client.list_tensorboard_experiments()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn delete_tensorboard_experiment(&self) -> DeleteTensorboardExperiment
pub fn delete_tensorboard_experiment(&self) -> DeleteTensorboardExperiment
Deletes a TensorboardExperiment.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService, name: &str
) -> Result<()> {
client.delete_tensorboard_experiment()
.set_name(name)
.poller().until_done().await?;
Ok(())
}Sourcepub fn create_tensorboard_run(&self) -> CreateTensorboardRun
pub fn create_tensorboard_run(&self) -> CreateTensorboardRun
Creates a TensorboardRun.
Example
use google_cloud_aiplatform_v1::model::TensorboardRun;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService, parent: &str
) -> Result<()> {
let response = client.create_tensorboard_run()
.set_parent(parent)
.set_tensorboard_run(
TensorboardRun::new()/* set fields */
)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn batch_create_tensorboard_runs(&self) -> BatchCreateTensorboardRuns
pub fn batch_create_tensorboard_runs(&self) -> BatchCreateTensorboardRuns
Batch create TensorboardRuns.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService
) -> Result<()> {
let response = client.batch_create_tensorboard_runs()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_tensorboard_run(&self) -> GetTensorboardRun
pub fn get_tensorboard_run(&self) -> GetTensorboardRun
Gets a TensorboardRun.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService, name: &str
) -> Result<()> {
let response = client.get_tensorboard_run()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_tensorboard_run(&self) -> UpdateTensorboardRun
pub fn update_tensorboard_run(&self) -> UpdateTensorboardRun
Updates a TensorboardRun.
Example
use google_cloud_wkt::FieldMask;
use google_cloud_aiplatform_v1::model::TensorboardRun;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService, name: &str
) -> Result<()> {
let response = client.update_tensorboard_run()
.set_tensorboard_run(
TensorboardRun::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_tensorboard_runs(&self) -> ListTensorboardRuns
pub fn list_tensorboard_runs(&self) -> ListTensorboardRuns
Lists TensorboardRuns in a Location.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService, parent: &str
) -> Result<()> {
let mut list = client.list_tensorboard_runs()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn delete_tensorboard_run(&self) -> DeleteTensorboardRun
pub fn delete_tensorboard_run(&self) -> DeleteTensorboardRun
Deletes a TensorboardRun.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService, name: &str
) -> Result<()> {
client.delete_tensorboard_run()
.set_name(name)
.poller().until_done().await?;
Ok(())
}Sourcepub fn batch_create_tensorboard_time_series(
&self,
) -> BatchCreateTensorboardTimeSeries
pub fn batch_create_tensorboard_time_series( &self, ) -> BatchCreateTensorboardTimeSeries
Batch create TensorboardTimeSeries that belong to a TensorboardExperiment.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService
) -> Result<()> {
let response = client.batch_create_tensorboard_time_series()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_tensorboard_time_series(&self) -> CreateTensorboardTimeSeries
pub fn create_tensorboard_time_series(&self) -> CreateTensorboardTimeSeries
Creates a TensorboardTimeSeries.
Example
use google_cloud_aiplatform_v1::model::TensorboardTimeSeries;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService, parent: &str
) -> Result<()> {
let response = client.create_tensorboard_time_series()
.set_parent(parent)
.set_tensorboard_time_series(
TensorboardTimeSeries::new()/* set fields */
)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_tensorboard_time_series(&self) -> GetTensorboardTimeSeries
pub fn get_tensorboard_time_series(&self) -> GetTensorboardTimeSeries
Gets a TensorboardTimeSeries.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService, name: &str
) -> Result<()> {
let response = client.get_tensorboard_time_series()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_tensorboard_time_series(&self) -> UpdateTensorboardTimeSeries
pub fn update_tensorboard_time_series(&self) -> UpdateTensorboardTimeSeries
Updates a TensorboardTimeSeries.
Example
use google_cloud_wkt::FieldMask;
use google_cloud_aiplatform_v1::model::TensorboardTimeSeries;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService, name: &str
) -> Result<()> {
let response = client.update_tensorboard_time_series()
.set_tensorboard_time_series(
TensorboardTimeSeries::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_tensorboard_time_series(&self) -> ListTensorboardTimeSeries
pub fn list_tensorboard_time_series(&self) -> ListTensorboardTimeSeries
Lists TensorboardTimeSeries in a Location.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService, parent: &str
) -> Result<()> {
let mut list = client.list_tensorboard_time_series()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn delete_tensorboard_time_series(&self) -> DeleteTensorboardTimeSeries
pub fn delete_tensorboard_time_series(&self) -> DeleteTensorboardTimeSeries
Deletes a TensorboardTimeSeries.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService, name: &str
) -> Result<()> {
client.delete_tensorboard_time_series()
.set_name(name)
.poller().until_done().await?;
Ok(())
}Sourcepub fn batch_read_tensorboard_time_series_data(
&self,
) -> BatchReadTensorboardTimeSeriesData
pub fn batch_read_tensorboard_time_series_data( &self, ) -> BatchReadTensorboardTimeSeriesData
Reads multiple TensorboardTimeSeries’ data. The data point number limit is 1000 for scalars, 100 for tensors and blob references. If the number of data points stored is less than the limit, all data is returned. Otherwise, the number limit of data points is randomly selected from this time series and returned.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService
) -> Result<()> {
let response = client.batch_read_tensorboard_time_series_data()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn read_tensorboard_time_series_data(&self) -> ReadTensorboardTimeSeriesData
pub fn read_tensorboard_time_series_data(&self) -> ReadTensorboardTimeSeriesData
Reads a TensorboardTimeSeries’ data. By default, if the number of data points stored is less than 1000, all data is returned. Otherwise, 1000 data points is randomly selected from this time series and returned. This value can be changed by changing max_data_points, which can’t be greater than 10k.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService
) -> Result<()> {
let response = client.read_tensorboard_time_series_data()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn write_tensorboard_experiment_data(
&self,
) -> WriteTensorboardExperimentData
pub fn write_tensorboard_experiment_data( &self, ) -> WriteTensorboardExperimentData
Write time series data points of multiple TensorboardTimeSeries in multiple TensorboardRun’s. If any data fail to be ingested, an error is returned.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService
) -> Result<()> {
let response = client.write_tensorboard_experiment_data()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn write_tensorboard_run_data(&self) -> WriteTensorboardRunData
pub fn write_tensorboard_run_data(&self) -> WriteTensorboardRunData
Write time series data points into multiple TensorboardTimeSeries under a TensorboardRun. If any data fail to be ingested, an error is returned.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService
) -> Result<()> {
let response = client.write_tensorboard_run_data()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn export_tensorboard_time_series_data(
&self,
) -> ExportTensorboardTimeSeriesData
pub fn export_tensorboard_time_series_data( &self, ) -> ExportTensorboardTimeSeriesData
Exports a TensorboardTimeSeries’ data. Data is returned in paginated responses.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService
) -> Result<()> {
let mut list = client.export_tensorboard_time_series_data()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn list_locations(&self) -> ListLocations
pub fn list_locations(&self) -> ListLocations
Lists information about the supported locations for this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService
) -> Result<()> {
let mut list = client.list_locations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_location(&self) -> GetLocation
pub fn get_location(&self) -> GetLocation
Gets information about a location.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService
) -> Result<()> {
let response = client.get_location()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn set_iam_policy(&self) -> SetIamPolicy
pub fn set_iam_policy(&self) -> SetIamPolicy
Sets the access control policy on the specified resource. Replaces any existing policy.
Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED
errors.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService
) -> Result<()> {
let response = client.set_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_iam_policy(&self) -> GetIamPolicy
pub fn get_iam_policy(&self) -> GetIamPolicy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService
) -> Result<()> {
let response = client.get_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn test_iam_permissions(&self) -> TestIamPermissions
pub fn test_iam_permissions(&self) -> TestIamPermissions
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of
permissions, not a NOT_FOUND error.
Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService
) -> Result<()> {
let response = client.test_iam_permissions()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn wait_operation(&self) -> WaitOperation
pub fn wait_operation(&self) -> WaitOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &TensorboardService
) -> Result<()> {
let response = client.wait_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Trait Implementations
Sourceimpl Clone for TensorboardService
impl Clone for TensorboardService
Sourcefn clone(&self) -> TensorboardService
fn clone(&self) -> TensorboardService
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more