#[non_exhaustive]pub enum DeleteOption {
SelectEntity(Box<SelectEntity>),
SelectTimeRangeAndFeature(Box<SelectTimeRangeAndFeature>),
}Available on crate feature
featurestore-service only.Expand description
Defines options to select feature values to be deleted.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
SelectEntity(Box<SelectEntity>)
Select feature values to be deleted by specifying entities.
SelectTimeRangeAndFeature(Box<SelectTimeRangeAndFeature>)
Select feature values to be deleted by specifying time range and features.