#[non_exhaustive]pub enum JobState {
Show 13 variants
Unspecified,
Queued,
Pending,
Running,
Succeeded,
Failed,
Cancelling,
Cancelled,
Paused,
Expired,
Updating,
PartiallySucceeded,
UnknownValue(UnknownValue),
}gen-ai-tuning-service or job-service or notebook-service or schedule-service only.Expand description
Describes the state of a job.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
The job state is unspecified.
Queued
The job has been just created or resumed and processing has not yet begun.
Pending
The service is preparing to run the job.
Running
The job is in progress.
Succeeded
The job completed successfully.
Failed
The job failed.
Cancelling
The job is being cancelled. From this state the job may only go to
either JOB_STATE_SUCCEEDED, JOB_STATE_FAILED or JOB_STATE_CANCELLED.
Cancelled
The job has been cancelled.
Paused
The job has been stopped, and can be resumed.
Expired
The job has expired.
Updating
The job is being updated. Only jobs in the RUNNING state can be updated.
After updating, the job goes back to the RUNNING state.
PartiallySucceeded
The job is partially succeeded, some results may be missing due to errors.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using JobState::value or JobState::name.