#[non_exhaustive]pub enum Encoding {
Unspecified,
Identity,
BagOfFeatures,
BagOfFeaturesSparse,
Indicator,
CombinedEmbedding,
ConcatEmbedding,
UnknownValue(UnknownValue),
}dataset-service or deployment-resource-pool-service or endpoint-service or job-service or model-service or pipeline-service only.Expand description
Defines how a feature is encoded. Defaults to IDENTITY.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Default value. This is the same as IDENTITY.
Identity
The tensor represents one feature.
BagOfFeatures
The tensor represents a bag of features where each index maps to a feature. InputMetadata.index_feature_mapping must be provided for this encoding. For example:
input = [27, 6.0, 150]
index_feature_mapping = ["age", "height", "weight"]BagOfFeaturesSparse
The tensor represents a bag of features where each index maps to a feature. Zero values in the tensor indicates feature being non-existent. InputMetadata.index_feature_mapping must be provided for this encoding. For example:
input = [2, 0, 5, 0, 1]
index_feature_mapping = ["a", "b", "c", "d", "e"]Indicator
The tensor is a list of binaries representing whether a feature exists or not (1 indicates existence). InputMetadata.index_feature_mapping must be provided for this encoding. For example:
input = [1, 0, 1, 0, 1]
index_feature_mapping = ["a", "b", "c", "d", "e"]CombinedEmbedding
The tensor is encoded into a 1-dimensional array represented by an encoded tensor. InputMetadata.encoded_tensor_name must be provided for this encoding. For example:
input = ["This", "is", "a", "test", "."]
encoded = [0.1, 0.2, 0.3, 0.4, 0.5]ConcatEmbedding
Select this encoding when the input tensor is encoded into a 2-dimensional array represented by an encoded tensor. InputMetadata.encoded_tensor_name must be provided for this encoding. The first dimension of the encoded tensor’s shape is the same as the input tensor’s shape. For example:
input = ["This", "is", "a", "test", "."]
encoded = [[0.1, 0.2, 0.3, 0.4, 0.5],
[0.2, 0.1, 0.4, 0.3, 0.5],
[0.5, 0.1, 0.3, 0.5, 0.4],
[0.5, 0.3, 0.1, 0.2, 0.4],
[0.4, 0.3, 0.2, 0.5, 0.1]]UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using Encoding::value or Encoding::name.