#[non_exhaustive]pub enum Method {
SampledShapleyAttribution(Box<SampledShapleyAttribution>),
IntegratedGradientsAttribution(Box<IntegratedGradientsAttribution>),
XraiAttribution(Box<XraiAttribution>),
Examples(Box<Examples>),
}dataset-service or deployment-resource-pool-service or endpoint-service or job-service or model-service or pipeline-service or prediction-service only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
SampledShapleyAttribution(Box<SampledShapleyAttribution>)
An attribution method that approximates Shapley values for features that contribute to the label being predicted. A sampling strategy is used to approximate the value rather than considering all subsets of features. Refer to this paper for model details: https://arxiv.org/abs/1306.4265.
IntegratedGradientsAttribution(Box<IntegratedGradientsAttribution>)
An attribution method that computes Aumann-Shapley values taking advantage of the model’s fully differentiable structure. Refer to this paper for more details: https://arxiv.org/abs/1703.01365
XraiAttribution(Box<XraiAttribution>)
An attribution method that redistributes Integrated Gradients attribution to segmented regions, taking advantage of the model’s fully differentiable structure. Refer to this paper for more details: https://arxiv.org/abs/1906.02825
XRAI currently performs better on natural images, like a picture of a house or an animal. If the images are taken in artificial environments, like a lab or manufacturing line, or from diagnostic equipment, like x-rays or quality-control cameras, use Integrated Gradients instead.
Examples(Box<Examples>)
Example-based explanations that returns the nearest neighbors from the provided dataset.