#[non_exhaustive]pub struct OutputConfig {
pub export_format_id: String,
pub artifact_destination: Option<GcsDestination>,
pub image_destination: Option<ContainerRegistryDestination>,
/* private fields */
}model-service only.Expand description
Output configuration for the Model export.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.export_format_id: StringThe ID of the format in which the Model must be exported. Each Model lists the export formats it supports. If no value is provided here, then the first from the list of the Model’s supported formats is used by default.
artifact_destination: Option<GcsDestination>The Cloud Storage location where the Model artifact is to be
written to. Under the directory given as the destination a new one with
name “model-export-<model-display-name>-<timestamp-of-export-call>”,
where timestamp is in YYYY-MM-DDThh:mm:ss.sssZ ISO-8601 format,
will be created. Inside, the Model and any of its supporting files
will be written.
This field should only be set when the exportableContent field of the
[Model.supported_export_formats] object contains ARTIFACT.
image_destination: Option<ContainerRegistryDestination>The Google Container Registry or Artifact Registry uri where the
Model container image will be copied to.
This field should only be set when the exportableContent field of the
[Model.supported_export_formats] object contains IMAGE.
Implementations
Sourceimpl OutputConfig
impl OutputConfig
Sourcepub fn set_export_format_id<T: Into<String>>(self, v: T) -> Self
pub fn set_export_format_id<T: Into<String>>(self, v: T) -> Self
Sets the value of export_format_id.
Example
let x = OutputConfig::new().set_export_format_id("example");Sourcepub fn set_artifact_destination<T>(self, v: T) -> Selfwhere
T: Into<GcsDestination>,
pub fn set_artifact_destination<T>(self, v: T) -> Selfwhere
T: Into<GcsDestination>,
Sets the value of artifact_destination.
Example
use google_cloud_aiplatform_v1::model::GcsDestination;
let x = OutputConfig::new().set_artifact_destination(GcsDestination::default()/* use setters */);Sourcepub fn set_or_clear_artifact_destination<T>(self, v: Option<T>) -> Selfwhere
T: Into<GcsDestination>,
pub fn set_or_clear_artifact_destination<T>(self, v: Option<T>) -> Selfwhere
T: Into<GcsDestination>,
Sets or clears the value of artifact_destination.
Example
use google_cloud_aiplatform_v1::model::GcsDestination;
let x = OutputConfig::new().set_or_clear_artifact_destination(Some(GcsDestination::default()/* use setters */));
let x = OutputConfig::new().set_or_clear_artifact_destination(None::<GcsDestination>);Sourcepub fn set_image_destination<T>(self, v: T) -> Selfwhere
T: Into<ContainerRegistryDestination>,
pub fn set_image_destination<T>(self, v: T) -> Selfwhere
T: Into<ContainerRegistryDestination>,
Sets the value of image_destination.
Example
use google_cloud_aiplatform_v1::model::ContainerRegistryDestination;
let x = OutputConfig::new().set_image_destination(ContainerRegistryDestination::default()/* use setters */);Sourcepub fn set_or_clear_image_destination<T>(self, v: Option<T>) -> Selfwhere
T: Into<ContainerRegistryDestination>,
pub fn set_or_clear_image_destination<T>(self, v: Option<T>) -> Selfwhere
T: Into<ContainerRegistryDestination>,
Sets or clears the value of image_destination.
Example
use google_cloud_aiplatform_v1::model::ContainerRegistryDestination;
let x = OutputConfig::new().set_or_clear_image_destination(Some(ContainerRegistryDestination::default()/* use setters */));
let x = OutputConfig::new().set_or_clear_image_destination(None::<ContainerRegistryDestination>);Trait Implementations
Sourceimpl Clone for OutputConfig
impl Clone for OutputConfig
Sourcefn clone(&self) -> OutputConfig
fn clone(&self) -> OutputConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for OutputConfig
impl Debug for OutputConfig
Sourceimpl Default for OutputConfig
impl Default for OutputConfig
Sourcefn default() -> OutputConfig
fn default() -> OutputConfig
Sourceimpl Message for OutputConfig
impl Message for OutputConfig
Sourceimpl PartialEq for OutputConfig
impl PartialEq for OutputConfig
impl StructuralPartialEq for OutputConfig