#[non_exhaustive]pub enum Source {
BigQuery(Box<BigQuery>),
}Available on crate feature
feature-registry-service only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BigQuery(Box<BigQuery>)
Indicates that features for this group come from BigQuery Table/View.
By default treats the source as a sparse time series source. The BigQuery
source table or view must have at least one entity ID column and a column
named feature_timestamp.