BigQuery

Struct BigQuery 

#[non_exhaustive]
pub struct BigQuery { pub big_query_source: Option<BigQuerySource>, pub entity_id_columns: Vec<String>, pub static_data_source: bool, pub time_series: Option<TimeSeries>, pub dense: bool, /* private fields */ }
Available on crate feature feature-registry-service only.
Input source type for BigQuery Tables and Views.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
big_query_source: Option<BigQuerySource>

Required. Immutable. The BigQuery source URI that points to either a BigQuery Table or View.

entity_id_columns: Vec<String>

Optional. Columns to construct entity_id / row keys. If not provided defaults to entity_id.

static_data_source: bool

Optional. Set if the data source is not a time-series.

time_series: Option<TimeSeries>

Optional. If the source is a time-series source, this can be set to control how downstream sources (ex: FeatureView ) will treat time-series sources. If not set, will treat the source as a time-series source with feature_timestamp as timestamp column and no scan boundary.

dense: bool

Optional. If set, all feature values will be fetched from a single row per unique entityId including nulls. If not set, will collapse all rows for each unique entityId into a singe row with any non-null values if present, if no non-null values are present will sync null. ex: If source has schema (entity_id, feature_timestamp, f0, f1) and the following rows: (e1, 2020-01-01T10:00:00.123Z, 10, 15) (e1, 2020-02-01T10:00:00.123Z, 20, null) If dense is set, (e1, 20, null) is synced to online stores. If dense is not set, (e1, 20, 15) is synced to online stores.

Implementations

Source

impl BigQuery

pub fn new() -> Self

pub fn set_big_query_source<T>(self, v: T) -> Self
where T: Into<BigQuerySource>,

Sets the value of big_query_source.

Example
use google_cloud_aiplatform_v1::model::BigQuerySource;
let x = BigQuery::new().set_big_query_source(BigQuerySource::default()/* use setters */);
pub fn set_or_clear_big_query_source<T>(self, v: Option<T>) -> Self
where T: Into<BigQuerySource>,

Sets or clears the value of big_query_source.

Example
use google_cloud_aiplatform_v1::model::BigQuerySource;
let x = BigQuery::new().set_or_clear_big_query_source(Some(BigQuerySource::default()/* use setters */));
let x = BigQuery::new().set_or_clear_big_query_source(None::<BigQuerySource>);
pub fn set_entity_id_columns<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of entity_id_columns.

Example
let x = BigQuery::new().set_entity_id_columns(["a", "b", "c"]);
pub fn set_static_data_source<T: Into<bool>>(self, v: T) -> Self

Sets the value of static_data_source.

Example
let x = BigQuery::new().set_static_data_source(true);
pub fn set_time_series<T>(self, v: T) -> Self
where T: Into<TimeSeries>,

Sets the value of time_series.

Example
use google_cloud_aiplatform_v1::model::feature_group::big_query::TimeSeries;
let x = BigQuery::new().set_time_series(TimeSeries::default()/* use setters */);
pub fn set_or_clear_time_series<T>(self, v: Option<T>) -> Self
where T: Into<TimeSeries>,

Sets or clears the value of time_series.

Example
use google_cloud_aiplatform_v1::model::feature_group::big_query::TimeSeries;
let x = BigQuery::new().set_or_clear_time_series(Some(TimeSeries::default()/* use setters */));
let x = BigQuery::new().set_or_clear_time_series(None::<TimeSeries>);
pub fn set_dense<T: Into<bool>>(self, v: T) -> Self

Sets the value of dense.

Example
let x = BigQuery::new().set_dense(true);