#[non_exhaustive]pub struct Metadata {
pub generate_time: Option<Timestamp>,
/* private fields */
}Available on crate features
feature-online-store-service or featurestore-online-serving-service only.Expand description
Metadata of feature value.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.generate_time: Option<Timestamp>Feature generation timestamp. Typically, it is provided by user at feature ingestion time. If not, feature store will use the system timestamp when the data is ingested into feature store.
Legacy Feature Store: For streaming ingestion, the time, aligned by days, must be no older than five years (1825 days) and no later than one year (366 days) in the future.
Implementations
Sourceimpl Metadata
impl Metadata
pub fn new() -> Self
Sourcepub fn set_generate_time<T>(self, v: T) -> Self
pub fn set_generate_time<T>(self, v: T) -> Self
Sets the value of generate_time.
Example
ⓘ
use wkt::Timestamp;
let x = Metadata::new().set_generate_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_generate_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_generate_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of generate_time.
Example
ⓘ
use wkt::Timestamp;
let x = Metadata::new().set_or_clear_generate_time(Some(Timestamp::default()/* use setters */));
let x = Metadata::new().set_or_clear_generate_time(None::<Timestamp>);Trait Implementations
impl StructuralPartialEq for Metadata