#[non_exhaustive]pub enum IndexUpdateMethod {
Unspecified,
BatchUpdate,
StreamUpdate,
UnknownValue(UnknownValue),
}index-service only.Expand description
The update method of an Index.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Should not be used.
BatchUpdate
BatchUpdate: user can call UpdateIndex with files on Cloud Storage of Datapoints to update.
StreamUpdate
StreamUpdate: user can call UpsertDatapoints/DeleteDatapoints to update the Index and the updates will be applied in corresponding DeployedIndexes in nearly real-time.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using IndexUpdateMethod::value or IndexUpdateMethod::name.
Implementations