#[non_exhaustive]pub struct MediaResolution {
pub value: Option<Value>,
/* private fields */
}Available on crate features
data-foundry-service or gen-ai-cache-service or gen-ai-tuning-service or llm-utility-service or prediction-service or vertex-rag-service only.Expand description
per part media resolution. Media resolution for the input media.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.value: Option<Value>Implementations
Sourceimpl MediaResolution
impl MediaResolution
pub fn new() -> Self
Sourcepub fn set_value<T: Into<Option<Value>>>(self, v: T) -> Self
pub fn set_value<T: Into<Option<Value>>>(self, v: T) -> Self
Sets the value of value.
Note that all the setters affecting value are mutually
exclusive.
Example
ⓘ
use google_cloud_aiplatform_v1::model::part::media_resolution::Level;
let x0 = MediaResolution::new().set_value(Some(
google_cloud_aiplatform_v1::model::part::media_resolution::Value::Level(Level::MediaResolutionLow)));
let x1 = MediaResolution::new().set_value(Some(
google_cloud_aiplatform_v1::model::part::media_resolution::Value::Level(Level::MediaResolutionMedium)));
let x2 = MediaResolution::new().set_value(Some(
google_cloud_aiplatform_v1::model::part::media_resolution::Value::Level(Level::MediaResolutionHigh)));Sourcepub fn level(&self) -> Option<&Level>
pub fn level(&self) -> Option<&Level>
The value of value
if it holds a Level, None if the field is not set or
holds a different branch.
Sourcepub fn set_level<T: Into<Level>>(self, v: T) -> Self
pub fn set_level<T: Into<Level>>(self, v: T) -> Self
Sets the value of value
to hold a Level.
Note that all the setters affecting value are
mutually exclusive.
Example
ⓘ
use google_cloud_aiplatform_v1::model::part::media_resolution::Level;
let x0 = MediaResolution::new().set_level(Level::MediaResolutionLow);
let x1 = MediaResolution::new().set_level(Level::MediaResolutionMedium);
let x2 = MediaResolution::new().set_level(Level::MediaResolutionHigh);
assert!(x0.level().is_some());
assert!(x1.level().is_some());
assert!(x2.level().is_some());Trait Implementations
Sourceimpl Clone for MediaResolution
impl Clone for MediaResolution
Sourcefn clone(&self) -> MediaResolution
fn clone(&self) -> MediaResolution
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MediaResolution
impl Debug for MediaResolution
Sourceimpl Default for MediaResolution
impl Default for MediaResolution
Sourcefn default() -> MediaResolution
fn default() -> MediaResolution
Returns the “default value” for a type. Read more
Sourceimpl Message for MediaResolution
impl Message for MediaResolution
Sourceimpl PartialEq for MediaResolution
impl PartialEq for MediaResolution
impl StructuralPartialEq for MediaResolution