#[non_exhaustive]pub enum Modality {
Unspecified,
Image,
Text,
Tabular,
UnknownValue(UnknownValue),
}Available on crate features
dataset-service or deployment-resource-pool-service or endpoint-service or job-service or model-service or pipeline-service or prediction-service only.Expand description
Preset option controlling parameters for different modalities
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unspecified
Should not be set. Added as a recommended best practice for enums
Image
IMAGE modality
Text
TEXT modality
Tabular
TABULAR modality
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using Modality::value or Modality::name.
Implementations