Strategy

Enum Strategy 

#[non_exhaustive]
pub enum Strategy { Unspecified, OnDemand, LowCost, Standard, Spot, FlexStart, UnknownValue(UnknownValue), }
Available on crate feature job-service only.
Optional. This determines which type of scheduling strategy to use. Right now users have two options such as STANDARD which will use regular on demand resources to schedule the job, the other is SPOT which would leverage spot resources alongwith regular resources to schedule the job.

Working with unknown values

This enum is defined as #[non_exhaustive] because Google Cloud may add additional enum variants at any time. Adding new variants is not considered a breaking change. Applications should write their code in anticipation of:

  • New values appearing in future releases of the client library, and
  • New values received dynamically, without application changes.

Please consult the Working with enums section in the user guide for some guidelines.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Unspecified

Strategy will default to STANDARD.



OnDemand

👎Deprecated

Deprecated. Regular on-demand provisioning strategy.



LowCost

👎Deprecated

Deprecated. Low cost by making potential use of spot resources.



Standard

Standard provisioning strategy uses regular on-demand resources.



Spot

Spot provisioning strategy uses spot resources.



FlexStart

Flex Start strategy uses DWS to queue for resources.



UnknownValue(UnknownValue)

If set, the enum was initialized with an unknown value.

Applications can examine the value using Strategy::value or Strategy::name.

Implementations

Source

impl Strategy

pub fn value(&self) -> Option<i32>

Gets the enum value.

Returns None if the enum contains an unknown value deserialized from the string representation of enums.

pub fn name(&self) -> Option<&str>

Gets the enum value as a string.

Returns None if the enum contains an unknown value deserialized from the integer representation of enums.