#[non_exhaustive]pub struct SlackChannels {
pub channels: Vec<SlackChannel>,
pub api_key_config: Option<ApiKeyConfig>,
/* private fields */
}Available on crate feature
vertex-rag-data-service only.Expand description
SlackChannels contains the Slack channels and corresponding access token.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channels: Vec<SlackChannel>Required. The Slack channel IDs.
api_key_config: Option<ApiKeyConfig>Required. The SecretManager secret version resource name (e.g. projects/{project}/secrets/{secret}/versions/{version}) storing the Slack channel access token that has access to the slack channel IDs. See: https://api.slack.com/tutorials/tracks/getting-a-token.
Implementations
Sourceimpl SlackChannels
impl SlackChannels
pub fn new() -> Self
Sourcepub fn set_channels<T, V>(self, v: T) -> Self
pub fn set_channels<T, V>(self, v: T) -> Self
Sourcepub fn set_api_key_config<T>(self, v: T) -> Selfwhere
T: Into<ApiKeyConfig>,
pub fn set_api_key_config<T>(self, v: T) -> Selfwhere
T: Into<ApiKeyConfig>,
Sets the value of api_key_config.
Example
ⓘ
use google_cloud_aiplatform_v1::model::api_auth::ApiKeyConfig;
let x = SlackChannels::new().set_api_key_config(ApiKeyConfig::default()/* use setters */);Sourcepub fn set_or_clear_api_key_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<ApiKeyConfig>,
pub fn set_or_clear_api_key_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<ApiKeyConfig>,
Sets or clears the value of api_key_config.
Example
ⓘ
use google_cloud_aiplatform_v1::model::api_auth::ApiKeyConfig;
let x = SlackChannels::new().set_or_clear_api_key_config(Some(ApiKeyConfig::default()/* use setters */));
let x = SlackChannels::new().set_or_clear_api_key_config(None::<ApiKeyConfig>);Trait Implementations
Sourceimpl Clone for SlackChannels
impl Clone for SlackChannels
Sourcefn clone(&self) -> SlackChannels
fn clone(&self) -> SlackChannels
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SlackChannels
impl Debug for SlackChannels
Sourceimpl Default for SlackChannels
impl Default for SlackChannels
Sourcefn default() -> SlackChannels
fn default() -> SlackChannels
Returns the “default value” for a type. Read more
Sourceimpl Message for SlackChannels
impl Message for SlackChannels
Sourceimpl PartialEq for SlackChannels
impl PartialEq for SlackChannels
impl StructuralPartialEq for SlackChannels