#[non_exhaustive]pub struct AsyncRetrieveContextsRequest {
pub parent: String,
pub query: Option<RagQuery>,
pub tools: Vec<Tool>,
/* private fields */
}Available on crate feature
vertex-rag-service only.Expand description
Request message for VertexRagService.AsyncRetrieveContexts.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The resource name of the Location from which to retrieve
RagContexts. The users must have permission to make a call in the project.
Format:
projects/{project}/locations/{location}.
query: Option<RagQuery>Required. Single RAG retrieve query.
tools: Vec<Tool>Optional. The tools to use for AskContexts.
Implementations