AutoraterConfig

Struct AutoraterConfig 

#[non_exhaustive]
pub struct AutoraterConfig { pub sampling_count: Option<i32>, pub flip_enabled: Option<bool>, pub autorater_model: String, pub generation_config: Option<GenerationConfig>, /* private fields */ }
Available on crate feature gen-ai-tuning-service only.
The configs for autorater. This is applicable to both EvaluateInstances and EvaluateDataset.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
sampling_count: Option<i32>

Optional. Number of samples for each instance in the dataset. If not specified, the default is 4. Minimum value is 1, maximum value is 32.

flip_enabled: Option<bool>

Optional. Default is true. Whether to flip the candidate and baseline responses. This is only applicable to the pairwise metric. If enabled, also provide PairwiseMetricSpec.candidate_response_field_name and PairwiseMetricSpec.baseline_response_field_name. When rendering PairwiseMetricSpec.metric_prompt_template, the candidate and baseline fields will be flipped for half of the samples to reduce bias.

autorater_model: String

Optional. The fully qualified name of the publisher model or tuned autorater endpoint to use.

Publisher model format: projects/{project}/locations/{location}/publishers/*/models/*

Tuned model endpoint format: projects/{project}/locations/{location}/endpoints/{endpoint}

generation_config: Option<GenerationConfig>

Optional. Configuration options for model generation and outputs.

Implementations

Source

impl AutoraterConfig

pub fn new() -> Self

pub fn set_sampling_count<T>(self, v: T) -> Self
where T: Into<i32>,

Sets the value of sampling_count.

Example
let x = AutoraterConfig::new().set_sampling_count(42);
pub fn set_or_clear_sampling_count<T>(self, v: Option<T>) -> Self
where T: Into<i32>,

Sets or clears the value of sampling_count.

Example
let x = AutoraterConfig::new().set_or_clear_sampling_count(Some(42));
let x = AutoraterConfig::new().set_or_clear_sampling_count(None::<i32>);
pub fn set_flip_enabled<T>(self, v: T) -> Self
where T: Into<bool>,

Sets the value of flip_enabled.

Example
let x = AutoraterConfig::new().set_flip_enabled(true);
pub fn set_or_clear_flip_enabled<T>(self, v: Option<T>) -> Self
where T: Into<bool>,

Sets or clears the value of flip_enabled.

Example
let x = AutoraterConfig::new().set_or_clear_flip_enabled(Some(false));
let x = AutoraterConfig::new().set_or_clear_flip_enabled(None::<bool>);
pub fn set_autorater_model<T: Into<String>>(self, v: T) -> Self

Sets the value of autorater_model.

Example
let x = AutoraterConfig::new().set_autorater_model("example");
pub fn set_generation_config<T>(self, v: T) -> Self

Sets the value of generation_config.

Example
use google_cloud_aiplatform_v1::model::GenerationConfig;
let x = AutoraterConfig::new().set_generation_config(GenerationConfig::default()/* use setters */);
pub fn set_or_clear_generation_config<T>(self, v: Option<T>) -> Self

Sets or clears the value of generation_config.

Example
use google_cloud_aiplatform_v1::model::GenerationConfig;
let x = AutoraterConfig::new().set_or_clear_generation_config(Some(GenerationConfig::default()/* use setters */));
let x = AutoraterConfig::new().set_or_clear_generation_config(None::<GenerationConfig>);