#[non_exhaustive]pub struct CreateEndpointOperationMetadata {
pub generic_metadata: Option<GenericOperationMetadata>,
pub deployment_stage: DeploymentStage,
/* private fields */
}Available on crate feature
endpoint-service only.Expand description
Runtime operation information for EndpointService.CreateEndpoint.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.generic_metadata: Option<GenericOperationMetadata>The operation generic information.
deployment_stage: DeploymentStageOutput only. The deployment stage of the model. Only populated if this CreateEndpoint request deploys a model at the same time.
Implementations
Sourceimpl CreateEndpointOperationMetadata
impl CreateEndpointOperationMetadata
pub fn new() -> Self
Sourcepub fn set_generic_metadata<T>(self, v: T) -> Selfwhere
T: Into<GenericOperationMetadata>,
pub fn set_generic_metadata<T>(self, v: T) -> Selfwhere
T: Into<GenericOperationMetadata>,
Sets the value of generic_metadata.
Example
ⓘ
use google_cloud_aiplatform_v1::model::GenericOperationMetadata;
let x = CreateEndpointOperationMetadata::new().set_generic_metadata(GenericOperationMetadata::default()/* use setters */);Sourcepub fn set_or_clear_generic_metadata<T>(self, v: Option<T>) -> Selfwhere
T: Into<GenericOperationMetadata>,
pub fn set_or_clear_generic_metadata<T>(self, v: Option<T>) -> Selfwhere
T: Into<GenericOperationMetadata>,
Sets or clears the value of generic_metadata.
Example
ⓘ
use google_cloud_aiplatform_v1::model::GenericOperationMetadata;
let x = CreateEndpointOperationMetadata::new().set_or_clear_generic_metadata(Some(GenericOperationMetadata::default()/* use setters */));
let x = CreateEndpointOperationMetadata::new().set_or_clear_generic_metadata(None::<GenericOperationMetadata>);Sourcepub fn set_deployment_stage<T: Into<DeploymentStage>>(self, v: T) -> Self
pub fn set_deployment_stage<T: Into<DeploymentStage>>(self, v: T) -> Self
Sets the value of deployment_stage.
Example
ⓘ
use google_cloud_aiplatform_v1::model::DeploymentStage;
let x0 = CreateEndpointOperationMetadata::new().set_deployment_stage(DeploymentStage::StartingDeployment);
let x1 = CreateEndpointOperationMetadata::new().set_deployment_stage(DeploymentStage::PreparingModel);
let x2 = CreateEndpointOperationMetadata::new().set_deployment_stage(DeploymentStage::CreatingServingCluster);Trait Implementations
Sourceimpl Clone for CreateEndpointOperationMetadata
impl Clone for CreateEndpointOperationMetadata
Sourcefn clone(&self) -> CreateEndpointOperationMetadata
fn clone(&self) -> CreateEndpointOperationMetadata
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for CreateEndpointOperationMetadata
impl Default for CreateEndpointOperationMetadata
Sourcefn default() -> CreateEndpointOperationMetadata
fn default() -> CreateEndpointOperationMetadata
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for CreateEndpointOperationMetadata
impl PartialEq for CreateEndpointOperationMetadata
Sourcefn eq(&self, other: &CreateEndpointOperationMetadata) -> bool
fn eq(&self, other: &CreateEndpointOperationMetadata) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CreateEndpointOperationMetadata