#[non_exhaustive]pub struct DeleteFeatureValuesResponse {
pub response: Option<Response>,
/* private fields */
}Available on crate feature
featurestore-service only.Expand description
Response message for FeaturestoreService.DeleteFeatureValues.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.response: Option<Response>Response based on which delete option is specified in the request
Implementations
Sourceimpl DeleteFeatureValuesResponse
impl DeleteFeatureValuesResponse
pub fn new() -> Self
Sourcepub fn set_response<T: Into<Option<Response>>>(self, v: T) -> Self
pub fn set_response<T: Into<Option<Response>>>(self, v: T) -> Self
Sets the value of response.
Note that all the setters affecting response are mutually
exclusive.
Example
ⓘ
use google_cloud_aiplatform_v1::model::delete_feature_values_response::SelectEntity;
let x = DeleteFeatureValuesResponse::new().set_response(Some(
google_cloud_aiplatform_v1::model::delete_feature_values_response::Response::SelectEntity(SelectEntity::default().into())));Sourcepub fn select_entity(&self) -> Option<&Box<SelectEntity>>
pub fn select_entity(&self) -> Option<&Box<SelectEntity>>
The value of response
if it holds a SelectEntity, None if the field is not set or
holds a different branch.
Sourcepub fn set_select_entity<T: Into<Box<SelectEntity>>>(self, v: T) -> Self
pub fn set_select_entity<T: Into<Box<SelectEntity>>>(self, v: T) -> Self
Sets the value of response
to hold a SelectEntity.
Note that all the setters affecting response are
mutually exclusive.
Example
ⓘ
use google_cloud_aiplatform_v1::model::delete_feature_values_response::SelectEntity;
let x = DeleteFeatureValuesResponse::new().set_select_entity(SelectEntity::default()/* use setters */);
assert!(x.select_entity().is_some());
assert!(x.select_time_range_and_feature().is_none());Sourcepub fn select_time_range_and_feature(
&self,
) -> Option<&Box<SelectTimeRangeAndFeature>>
pub fn select_time_range_and_feature( &self, ) -> Option<&Box<SelectTimeRangeAndFeature>>
The value of response
if it holds a SelectTimeRangeAndFeature, None if the field is not set or
holds a different branch.
Sourcepub fn set_select_time_range_and_feature<T: Into<Box<SelectTimeRangeAndFeature>>>(
self,
v: T,
) -> Self
pub fn set_select_time_range_and_feature<T: Into<Box<SelectTimeRangeAndFeature>>>( self, v: T, ) -> Self
Sets the value of response
to hold a SelectTimeRangeAndFeature.
Note that all the setters affecting response are
mutually exclusive.
Example
ⓘ
use google_cloud_aiplatform_v1::model::delete_feature_values_response::SelectTimeRangeAndFeature;
let x = DeleteFeatureValuesResponse::new().set_select_time_range_and_feature(SelectTimeRangeAndFeature::default()/* use setters */);
assert!(x.select_time_range_and_feature().is_some());
assert!(x.select_entity().is_none());Trait Implementations
Sourceimpl Clone for DeleteFeatureValuesResponse
impl Clone for DeleteFeatureValuesResponse
Sourcefn clone(&self) -> DeleteFeatureValuesResponse
fn clone(&self) -> DeleteFeatureValuesResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeleteFeatureValuesResponse
impl Debug for DeleteFeatureValuesResponse
Sourceimpl Default for DeleteFeatureValuesResponse
impl Default for DeleteFeatureValuesResponse
Sourcefn default() -> DeleteFeatureValuesResponse
fn default() -> DeleteFeatureValuesResponse
Returns the “default value” for a type. Read more
impl StructuralPartialEq for DeleteFeatureValuesResponse