#[non_exhaustive]pub struct EvaluationDataset {
pub source: Option<Source>,
/* private fields */
}Available on crate feature
gen-ai-tuning-service only.Expand description
The dataset used for evaluation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source: Option<Source>The source of the dataset.
Implementations
Sourceimpl EvaluationDataset
impl EvaluationDataset
pub fn new() -> Self
Sourcepub fn set_source<T: Into<Option<Source>>>(self, v: T) -> Self
pub fn set_source<T: Into<Option<Source>>>(self, v: T) -> Self
Sets the value of source.
Note that all the setters affecting source are mutually
exclusive.
Example
ⓘ
use google_cloud_aiplatform_v1::model::GcsSource;
let x = EvaluationDataset::new().set_source(Some(
google_cloud_aiplatform_v1::model::evaluation_dataset::Source::GcsSource(GcsSource::default().into())));Sourcepub fn gcs_source(&self) -> Option<&Box<GcsSource>>
pub fn gcs_source(&self) -> Option<&Box<GcsSource>>
The value of source
if it holds a GcsSource, None if the field is not set or
holds a different branch.
Sourcepub fn set_gcs_source<T: Into<Box<GcsSource>>>(self, v: T) -> Self
pub fn set_gcs_source<T: Into<Box<GcsSource>>>(self, v: T) -> Self
Sets the value of source
to hold a GcsSource.
Note that all the setters affecting source are
mutually exclusive.
Example
ⓘ
use google_cloud_aiplatform_v1::model::GcsSource;
let x = EvaluationDataset::new().set_gcs_source(GcsSource::default()/* use setters */);
assert!(x.gcs_source().is_some());
assert!(x.bigquery_source().is_none());Sourcepub fn bigquery_source(&self) -> Option<&Box<BigQuerySource>>
pub fn bigquery_source(&self) -> Option<&Box<BigQuerySource>>
The value of source
if it holds a BigquerySource, None if the field is not set or
holds a different branch.
Sourcepub fn set_bigquery_source<T: Into<Box<BigQuerySource>>>(self, v: T) -> Self
pub fn set_bigquery_source<T: Into<Box<BigQuerySource>>>(self, v: T) -> Self
Sets the value of source
to hold a BigquerySource.
Note that all the setters affecting source are
mutually exclusive.
Example
ⓘ
use google_cloud_aiplatform_v1::model::BigQuerySource;
let x = EvaluationDataset::new().set_bigquery_source(BigQuerySource::default()/* use setters */);
assert!(x.bigquery_source().is_some());
assert!(x.gcs_source().is_none());Trait Implementations
Sourceimpl Clone for EvaluationDataset
impl Clone for EvaluationDataset
Sourcefn clone(&self) -> EvaluationDataset
fn clone(&self) -> EvaluationDataset
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EvaluationDataset
impl Debug for EvaluationDataset
Sourceimpl Default for EvaluationDataset
impl Default for EvaluationDataset
Sourcefn default() -> EvaluationDataset
fn default() -> EvaluationDataset
Returns the “default value” for a type. Read more
Sourceimpl Message for EvaluationDataset
impl Message for EvaluationDataset
Sourceimpl PartialEq for EvaluationDataset
impl PartialEq for EvaluationDataset
impl StructuralPartialEq for EvaluationDataset