#[non_exhaustive]pub struct Event {
pub artifact: String,
pub execution: String,
pub event_time: Option<Timestamp>,
pub type: Type,
pub labels: HashMap<String, String>,
/* private fields */
}metadata-service only.Expand description
An edge describing the relationship between an Artifact and an Execution in a lineage graph.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.artifact: StringRequired. The relative resource name of the Artifact in the Event.
execution: StringOutput only. The relative resource name of the Execution in the Event.
event_time: Option<Timestamp>Output only. Time the Event occurred.
type: TypeRequired. The type of the Event.
labels: HashMap<String, String>The labels with user-defined metadata to annotate Events.
Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one Event (System labels are excluded).
See https://goo.gl/xmQnxf for more information and examples of labels. System reserved label keys are prefixed with “aiplatform.googleapis.com/” and are immutable.
Implementations
Sourceimpl Event
impl Event
Sourcepub fn set_artifact<T: Into<String>>(self, v: T) -> Self
pub fn set_artifact<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_execution<T: Into<String>>(self, v: T) -> Self
pub fn set_execution<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_event_time<T>(self, v: T) -> Self
pub fn set_event_time<T>(self, v: T) -> Self
Sets the value of event_time.
Example
use wkt::Timestamp;
let x = Event::new().set_event_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_event_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_event_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of event_time.
Example
use wkt::Timestamp;
let x = Event::new().set_or_clear_event_time(Some(Timestamp::default()/* use setters */));
let x = Event::new().set_or_clear_event_time(None::<Timestamp>);Trait Implementations
impl StructuralPartialEq for Event