#[non_exhaustive]pub struct ExplanationParameters {
pub top_k: i32,
pub output_indices: Option<ListValue>,
pub method: Option<Method>,
/* private fields */
}dataset-service or deployment-resource-pool-service or endpoint-service or job-service or model-service or pipeline-service or prediction-service only.Expand description
Parameters to configure explaining for Model’s predictions.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.top_k: i32If populated, returns attributions for top K indices of outputs (defaults to 1). Only applies to Models that predicts more than one outputs (e,g, multi-class Models). When set to -1, returns explanations for all outputs.
output_indices: Option<ListValue>If populated, only returns attributions that have output_index contained in output_indices. It must be an ndarray of integers, with the same shape of the output it’s explaining.
If not populated, returns attributions for top_k indices of outputs. If neither top_k nor output_indices is populated, returns the argmax index of the outputs.
Only applicable to Models that predict multiple outputs (e,g, multi-class Models that predict multiple classes).
method: Option<Method>Implementations
Sourceimpl ExplanationParameters
impl ExplanationParameters
Sourcepub fn set_output_indices<T>(self, v: T) -> Self
pub fn set_output_indices<T>(self, v: T) -> Self
Sets the value of output_indices.
Example
use wkt::ListValue;
let x = ExplanationParameters::new().set_output_indices(ListValue::default()/* use setters */);Sourcepub fn set_or_clear_output_indices<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_output_indices<T>(self, v: Option<T>) -> Self
Sets or clears the value of output_indices.
Example
use wkt::ListValue;
let x = ExplanationParameters::new().set_or_clear_output_indices(Some(ListValue::default()/* use setters */));
let x = ExplanationParameters::new().set_or_clear_output_indices(None::<ListValue>);Sourcepub fn set_method<T: Into<Option<Method>>>(self, v: T) -> Self
pub fn set_method<T: Into<Option<Method>>>(self, v: T) -> Self
Sets the value of method.
Note that all the setters affecting method are mutually
exclusive.
Example
use google_cloud_aiplatform_v1::model::SampledShapleyAttribution;
let x = ExplanationParameters::new().set_method(Some(
google_cloud_aiplatform_v1::model::explanation_parameters::Method::SampledShapleyAttribution(SampledShapleyAttribution::default().into())));Sourcepub fn sampled_shapley_attribution(
&self,
) -> Option<&Box<SampledShapleyAttribution>>
pub fn sampled_shapley_attribution( &self, ) -> Option<&Box<SampledShapleyAttribution>>
The value of method
if it holds a SampledShapleyAttribution, None if the field is not set or
holds a different branch.
Sourcepub fn set_sampled_shapley_attribution<T: Into<Box<SampledShapleyAttribution>>>(
self,
v: T,
) -> Self
pub fn set_sampled_shapley_attribution<T: Into<Box<SampledShapleyAttribution>>>( self, v: T, ) -> Self
Sets the value of method
to hold a SampledShapleyAttribution.
Note that all the setters affecting method are
mutually exclusive.
Example
use google_cloud_aiplatform_v1::model::SampledShapleyAttribution;
let x = ExplanationParameters::new().set_sampled_shapley_attribution(SampledShapleyAttribution::default()/* use setters */);
assert!(x.sampled_shapley_attribution().is_some());
assert!(x.integrated_gradients_attribution().is_none());
assert!(x.xrai_attribution().is_none());
assert!(x.examples().is_none());Sourcepub fn integrated_gradients_attribution(
&self,
) -> Option<&Box<IntegratedGradientsAttribution>>
pub fn integrated_gradients_attribution( &self, ) -> Option<&Box<IntegratedGradientsAttribution>>
The value of method
if it holds a IntegratedGradientsAttribution, None if the field is not set or
holds a different branch.
Sourcepub fn set_integrated_gradients_attribution<T: Into<Box<IntegratedGradientsAttribution>>>(
self,
v: T,
) -> Self
pub fn set_integrated_gradients_attribution<T: Into<Box<IntegratedGradientsAttribution>>>( self, v: T, ) -> Self
Sets the value of method
to hold a IntegratedGradientsAttribution.
Note that all the setters affecting method are
mutually exclusive.
Example
use google_cloud_aiplatform_v1::model::IntegratedGradientsAttribution;
let x = ExplanationParameters::new().set_integrated_gradients_attribution(IntegratedGradientsAttribution::default()/* use setters */);
assert!(x.integrated_gradients_attribution().is_some());
assert!(x.sampled_shapley_attribution().is_none());
assert!(x.xrai_attribution().is_none());
assert!(x.examples().is_none());Sourcepub fn xrai_attribution(&self) -> Option<&Box<XraiAttribution>>
pub fn xrai_attribution(&self) -> Option<&Box<XraiAttribution>>
The value of method
if it holds a XraiAttribution, None if the field is not set or
holds a different branch.
Sourcepub fn set_xrai_attribution<T: Into<Box<XraiAttribution>>>(self, v: T) -> Self
pub fn set_xrai_attribution<T: Into<Box<XraiAttribution>>>(self, v: T) -> Self
Sets the value of method
to hold a XraiAttribution.
Note that all the setters affecting method are
mutually exclusive.
Example
use google_cloud_aiplatform_v1::model::XraiAttribution;
let x = ExplanationParameters::new().set_xrai_attribution(XraiAttribution::default()/* use setters */);
assert!(x.xrai_attribution().is_some());
assert!(x.sampled_shapley_attribution().is_none());
assert!(x.integrated_gradients_attribution().is_none());
assert!(x.examples().is_none());Sourcepub fn examples(&self) -> Option<&Box<Examples>>
pub fn examples(&self) -> Option<&Box<Examples>>
The value of method
if it holds a Examples, None if the field is not set or
holds a different branch.
Sourcepub fn set_examples<T: Into<Box<Examples>>>(self, v: T) -> Self
pub fn set_examples<T: Into<Box<Examples>>>(self, v: T) -> Self
Sets the value of method
to hold a Examples.
Note that all the setters affecting method are
mutually exclusive.
Example
use google_cloud_aiplatform_v1::model::Examples;
let x = ExplanationParameters::new().set_examples(Examples::default()/* use setters */);
assert!(x.examples().is_some());
assert!(x.sampled_shapley_attribution().is_none());
assert!(x.integrated_gradients_attribution().is_none());
assert!(x.xrai_attribution().is_none());Trait Implementations
Sourceimpl Clone for ExplanationParameters
impl Clone for ExplanationParameters
Sourcefn clone(&self) -> ExplanationParameters
fn clone(&self) -> ExplanationParameters
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ExplanationParameters
impl Debug for ExplanationParameters
Sourceimpl Default for ExplanationParameters
impl Default for ExplanationParameters
Sourcefn default() -> ExplanationParameters
fn default() -> ExplanationParameters
Sourceimpl Message for ExplanationParameters
impl Message for ExplanationParameters
Sourceimpl PartialEq for ExplanationParameters
impl PartialEq for ExplanationParameters
impl StructuralPartialEq for ExplanationParameters