#[non_exhaustive]pub struct ExportFeatureValuesRequest {
pub entity_type: String,
pub destination: Option<FeatureValueDestination>,
pub feature_selector: Option<FeatureSelector>,
pub settings: Vec<DestinationFeatureSetting>,
pub mode: Option<Mode>,
/* private fields */
}featurestore-service only.Expand description
Request message for FeaturestoreService.ExportFeatureValues.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.entity_type: StringRequired. The resource name of the EntityType from which to export Feature
values. Format:
projects/{project}/locations/{location}/featurestores/{featurestore}/entityTypes/{entity_type}
destination: Option<FeatureValueDestination>Required. Specifies destination location and format.
feature_selector: Option<FeatureSelector>Required. Selects Features to export values of.
settings: Vec<DestinationFeatureSetting>Per-Feature export settings.
mode: Option<Mode>Required. The mode in which Feature values are exported.
Implementations
Sourceimpl ExportFeatureValuesRequest
impl ExportFeatureValuesRequest
Sourcepub fn set_entity_type<T: Into<String>>(self, v: T) -> Self
pub fn set_entity_type<T: Into<String>>(self, v: T) -> Self
Sets the value of entity_type.
Example
let x = ExportFeatureValuesRequest::new().set_entity_type(format!("projects/{project_id}/locations/{location_id}/featurestores/{featurestore_id}/entityTypes/{entity_type_id}"));Sourcepub fn set_destination<T>(self, v: T) -> Selfwhere
T: Into<FeatureValueDestination>,
pub fn set_destination<T>(self, v: T) -> Selfwhere
T: Into<FeatureValueDestination>,
Sets the value of destination.
Example
use google_cloud_aiplatform_v1::model::FeatureValueDestination;
let x = ExportFeatureValuesRequest::new().set_destination(FeatureValueDestination::default()/* use setters */);Sourcepub fn set_or_clear_destination<T>(self, v: Option<T>) -> Selfwhere
T: Into<FeatureValueDestination>,
pub fn set_or_clear_destination<T>(self, v: Option<T>) -> Selfwhere
T: Into<FeatureValueDestination>,
Sets or clears the value of destination.
Example
use google_cloud_aiplatform_v1::model::FeatureValueDestination;
let x = ExportFeatureValuesRequest::new().set_or_clear_destination(Some(FeatureValueDestination::default()/* use setters */));
let x = ExportFeatureValuesRequest::new().set_or_clear_destination(None::<FeatureValueDestination>);Sourcepub fn set_feature_selector<T>(self, v: T) -> Selfwhere
T: Into<FeatureSelector>,
pub fn set_feature_selector<T>(self, v: T) -> Selfwhere
T: Into<FeatureSelector>,
Sets the value of feature_selector.
Example
use google_cloud_aiplatform_v1::model::FeatureSelector;
let x = ExportFeatureValuesRequest::new().set_feature_selector(FeatureSelector::default()/* use setters */);Sourcepub fn set_or_clear_feature_selector<T>(self, v: Option<T>) -> Selfwhere
T: Into<FeatureSelector>,
pub fn set_or_clear_feature_selector<T>(self, v: Option<T>) -> Selfwhere
T: Into<FeatureSelector>,
Sets or clears the value of feature_selector.
Example
use google_cloud_aiplatform_v1::model::FeatureSelector;
let x = ExportFeatureValuesRequest::new().set_or_clear_feature_selector(Some(FeatureSelector::default()/* use setters */));
let x = ExportFeatureValuesRequest::new().set_or_clear_feature_selector(None::<FeatureSelector>);Sourcepub fn set_settings<T, V>(self, v: T) -> Self
pub fn set_settings<T, V>(self, v: T) -> Self
Sourcepub fn set_mode<T: Into<Option<Mode>>>(self, v: T) -> Self
pub fn set_mode<T: Into<Option<Mode>>>(self, v: T) -> Self
Sets the value of mode.
Note that all the setters affecting mode are mutually
exclusive.
Example
use google_cloud_aiplatform_v1::model::export_feature_values_request::SnapshotExport;
let x = ExportFeatureValuesRequest::new().set_mode(Some(
google_cloud_aiplatform_v1::model::export_feature_values_request::Mode::SnapshotExport(SnapshotExport::default().into())));Sourcepub fn snapshot_export(&self) -> Option<&Box<SnapshotExport>>
pub fn snapshot_export(&self) -> Option<&Box<SnapshotExport>>
The value of mode
if it holds a SnapshotExport, None if the field is not set or
holds a different branch.
Sourcepub fn set_snapshot_export<T: Into<Box<SnapshotExport>>>(self, v: T) -> Self
pub fn set_snapshot_export<T: Into<Box<SnapshotExport>>>(self, v: T) -> Self
Sets the value of mode
to hold a SnapshotExport.
Note that all the setters affecting mode are
mutually exclusive.
Example
use google_cloud_aiplatform_v1::model::export_feature_values_request::SnapshotExport;
let x = ExportFeatureValuesRequest::new().set_snapshot_export(SnapshotExport::default()/* use setters */);
assert!(x.snapshot_export().is_some());
assert!(x.full_export().is_none());Sourcepub fn full_export(&self) -> Option<&Box<FullExport>>
pub fn full_export(&self) -> Option<&Box<FullExport>>
The value of mode
if it holds a FullExport, None if the field is not set or
holds a different branch.
Sourcepub fn set_full_export<T: Into<Box<FullExport>>>(self, v: T) -> Self
pub fn set_full_export<T: Into<Box<FullExport>>>(self, v: T) -> Self
Sets the value of mode
to hold a FullExport.
Note that all the setters affecting mode are
mutually exclusive.
Example
use google_cloud_aiplatform_v1::model::export_feature_values_request::FullExport;
let x = ExportFeatureValuesRequest::new().set_full_export(FullExport::default()/* use setters */);
assert!(x.full_export().is_some());
assert!(x.snapshot_export().is_none());Trait Implementations
Sourceimpl Clone for ExportFeatureValuesRequest
impl Clone for ExportFeatureValuesRequest
Sourcefn clone(&self) -> ExportFeatureValuesRequest
fn clone(&self) -> ExportFeatureValuesRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ExportFeatureValuesRequest
impl Debug for ExportFeatureValuesRequest
Sourceimpl Default for ExportFeatureValuesRequest
impl Default for ExportFeatureValuesRequest
Sourcefn default() -> ExportFeatureValuesRequest
fn default() -> ExportFeatureValuesRequest
Sourceimpl Message for ExportFeatureValuesRequest
impl Message for ExportFeatureValuesRequest
impl StructuralPartialEq for ExportFeatureValuesRequest