#[non_exhaustive]pub struct FeatureNoiseSigma {
pub noise_sigma: Vec<NoiseSigmaForFeature>,
/* private fields */
}Available on crate features
dataset-service or deployment-resource-pool-service or endpoint-service or job-service or model-service or pipeline-service or prediction-service only.Expand description
Noise sigma by features. Noise sigma represents the standard deviation of the gaussian kernel that will be used to add noise to interpolated inputs prior to computing gradients.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.noise_sigma: Vec<NoiseSigmaForFeature>Noise sigma per feature. No noise is added to features that are not set.
Implementations
Sourceimpl FeatureNoiseSigma
impl FeatureNoiseSigma
Sourcepub fn set_noise_sigma<T, V>(self, v: T) -> Self
pub fn set_noise_sigma<T, V>(self, v: T) -> Self
Sets the value of noise_sigma.
Example
ⓘ
use google_cloud_aiplatform_v1::model::feature_noise_sigma::NoiseSigmaForFeature;
let x = FeatureNoiseSigma::new()
.set_noise_sigma([
NoiseSigmaForFeature::default()/* use setters */,
NoiseSigmaForFeature::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for FeatureNoiseSigma
impl Clone for FeatureNoiseSigma
Sourcefn clone(&self) -> FeatureNoiseSigma
fn clone(&self) -> FeatureNoiseSigma
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FeatureNoiseSigma
impl Debug for FeatureNoiseSigma
Sourceimpl Default for FeatureNoiseSigma
impl Default for FeatureNoiseSigma
Sourcefn default() -> FeatureNoiseSigma
fn default() -> FeatureNoiseSigma
Returns the “default value” for a type. Read more
Sourceimpl Message for FeatureNoiseSigma
impl Message for FeatureNoiseSigma
Sourceimpl PartialEq for FeatureNoiseSigma
impl PartialEq for FeatureNoiseSigma
Sourcefn eq(&self, other: &FeatureNoiseSigma) -> bool
fn eq(&self, other: &FeatureNoiseSigma) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for FeatureNoiseSigma