#[non_exhaustive]pub struct FeatureValueDestination {
pub destination: Option<Destination>,
/* private fields */
}featurestore-service only.Expand description
A destination location for Feature values and format.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.destination: Option<Destination>Implementations
Sourceimpl FeatureValueDestination
impl FeatureValueDestination
Sourcepub fn set_destination<T: Into<Option<Destination>>>(self, v: T) -> Self
pub fn set_destination<T: Into<Option<Destination>>>(self, v: T) -> Self
Sets the value of destination.
Note that all the setters affecting destination are mutually
exclusive.
Example
use google_cloud_aiplatform_v1::model::BigQueryDestination;
let x = FeatureValueDestination::new().set_destination(Some(
google_cloud_aiplatform_v1::model::feature_value_destination::Destination::BigqueryDestination(BigQueryDestination::default().into())));Sourcepub fn bigquery_destination(&self) -> Option<&Box<BigQueryDestination>>
pub fn bigquery_destination(&self) -> Option<&Box<BigQueryDestination>>
The value of destination
if it holds a BigqueryDestination, None if the field is not set or
holds a different branch.
Sourcepub fn set_bigquery_destination<T: Into<Box<BigQueryDestination>>>(
self,
v: T,
) -> Self
pub fn set_bigquery_destination<T: Into<Box<BigQueryDestination>>>( self, v: T, ) -> Self
Sets the value of destination
to hold a BigqueryDestination.
Note that all the setters affecting destination are
mutually exclusive.
Example
use google_cloud_aiplatform_v1::model::BigQueryDestination;
let x = FeatureValueDestination::new().set_bigquery_destination(BigQueryDestination::default()/* use setters */);
assert!(x.bigquery_destination().is_some());
assert!(x.tfrecord_destination().is_none());
assert!(x.csv_destination().is_none());Sourcepub fn tfrecord_destination(&self) -> Option<&Box<TFRecordDestination>>
pub fn tfrecord_destination(&self) -> Option<&Box<TFRecordDestination>>
The value of destination
if it holds a TfrecordDestination, None if the field is not set or
holds a different branch.
Sourcepub fn set_tfrecord_destination<T: Into<Box<TFRecordDestination>>>(
self,
v: T,
) -> Self
pub fn set_tfrecord_destination<T: Into<Box<TFRecordDestination>>>( self, v: T, ) -> Self
Sets the value of destination
to hold a TfrecordDestination.
Note that all the setters affecting destination are
mutually exclusive.
Example
use google_cloud_aiplatform_v1::model::TFRecordDestination;
let x = FeatureValueDestination::new().set_tfrecord_destination(TFRecordDestination::default()/* use setters */);
assert!(x.tfrecord_destination().is_some());
assert!(x.bigquery_destination().is_none());
assert!(x.csv_destination().is_none());Sourcepub fn csv_destination(&self) -> Option<&Box<CsvDestination>>
pub fn csv_destination(&self) -> Option<&Box<CsvDestination>>
The value of destination
if it holds a CsvDestination, None if the field is not set or
holds a different branch.
Sourcepub fn set_csv_destination<T: Into<Box<CsvDestination>>>(self, v: T) -> Self
pub fn set_csv_destination<T: Into<Box<CsvDestination>>>(self, v: T) -> Self
Sets the value of destination
to hold a CsvDestination.
Note that all the setters affecting destination are
mutually exclusive.
Example
use google_cloud_aiplatform_v1::model::CsvDestination;
let x = FeatureValueDestination::new().set_csv_destination(CsvDestination::default()/* use setters */);
assert!(x.csv_destination().is_some());
assert!(x.bigquery_destination().is_none());
assert!(x.tfrecord_destination().is_none());Trait Implementations
Sourceimpl Clone for FeatureValueDestination
impl Clone for FeatureValueDestination
Sourcefn clone(&self) -> FeatureValueDestination
fn clone(&self) -> FeatureValueDestination
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for FeatureValueDestination
impl Debug for FeatureValueDestination
Sourceimpl Default for FeatureValueDestination
impl Default for FeatureValueDestination
Sourcefn default() -> FeatureValueDestination
fn default() -> FeatureValueDestination
Sourceimpl Message for FeatureValueDestination
impl Message for FeatureValueDestination
Sourceimpl PartialEq for FeatureValueDestination
impl PartialEq for FeatureValueDestination
impl StructuralPartialEq for FeatureValueDestination