#[non_exhaustive]pub struct GoogleMaps {
pub enable_widget: bool,
/* private fields */
}Available on crate features
gen-ai-cache-service or llm-utility-service or prediction-service or vertex-rag-service only.Expand description
Tool to retrieve public maps data for grounding, powered by Google.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.enable_widget: boolIf true, include the widget context token in the response.
Implementations
Sourceimpl GoogleMaps
impl GoogleMaps
Sourcepub fn set_enable_widget<T: Into<bool>>(self, v: T) -> Self
pub fn set_enable_widget<T: Into<bool>>(self, v: T) -> Self