#[non_exhaustive]pub struct ImportFeatureValuesOperationMetadata {
pub generic_metadata: Option<GenericOperationMetadata>,
pub imported_entity_count: i64,
pub imported_feature_value_count: i64,
pub source_uris: Vec<String>,
pub invalid_row_count: i64,
pub timestamp_outside_retention_rows_count: i64,
pub blocking_operation_ids: Vec<i64>,
/* private fields */
}featurestore-service only.Expand description
Details of operations that perform import Feature values.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.generic_metadata: Option<GenericOperationMetadata>Operation metadata for Featurestore import Feature values.
imported_entity_count: i64Number of entities that have been imported by the operation.
imported_feature_value_count: i64Number of Feature values that have been imported by the operation.
source_uris: Vec<String>The source URI from where Feature values are imported.
invalid_row_count: i64The number of rows in input source that weren’t imported due to either
- Not having any featureValues.
- Having a null entityId.
- Having a null timestamp.
- Not being parsable (applicable for CSV sources).
timestamp_outside_retention_rows_count: i64The number rows that weren’t ingested due to having timestamps outside the retention boundary.
blocking_operation_ids: Vec<i64>List of ImportFeatureValues operations running under a single EntityType that are blocking this operation.
Implementations
Sourceimpl ImportFeatureValuesOperationMetadata
impl ImportFeatureValuesOperationMetadata
Sourcepub fn set_generic_metadata<T>(self, v: T) -> Selfwhere
T: Into<GenericOperationMetadata>,
pub fn set_generic_metadata<T>(self, v: T) -> Selfwhere
T: Into<GenericOperationMetadata>,
Sets the value of generic_metadata.
Example
use google_cloud_aiplatform_v1::model::GenericOperationMetadata;
let x = ImportFeatureValuesOperationMetadata::new().set_generic_metadata(GenericOperationMetadata::default()/* use setters */);Sourcepub fn set_or_clear_generic_metadata<T>(self, v: Option<T>) -> Selfwhere
T: Into<GenericOperationMetadata>,
pub fn set_or_clear_generic_metadata<T>(self, v: Option<T>) -> Selfwhere
T: Into<GenericOperationMetadata>,
Sets or clears the value of generic_metadata.
Example
use google_cloud_aiplatform_v1::model::GenericOperationMetadata;
let x = ImportFeatureValuesOperationMetadata::new().set_or_clear_generic_metadata(Some(GenericOperationMetadata::default()/* use setters */));
let x = ImportFeatureValuesOperationMetadata::new().set_or_clear_generic_metadata(None::<GenericOperationMetadata>);Sourcepub fn set_imported_entity_count<T: Into<i64>>(self, v: T) -> Self
pub fn set_imported_entity_count<T: Into<i64>>(self, v: T) -> Self
Sets the value of imported_entity_count.
Example
let x = ImportFeatureValuesOperationMetadata::new().set_imported_entity_count(42);Sourcepub fn set_imported_feature_value_count<T: Into<i64>>(self, v: T) -> Self
pub fn set_imported_feature_value_count<T: Into<i64>>(self, v: T) -> Self
Sets the value of imported_feature_value_count.
Example
let x = ImportFeatureValuesOperationMetadata::new().set_imported_feature_value_count(42);Sourcepub fn set_source_uris<T, V>(self, v: T) -> Self
pub fn set_source_uris<T, V>(self, v: T) -> Self
Sets the value of source_uris.
Example
let x = ImportFeatureValuesOperationMetadata::new().set_source_uris(["a", "b", "c"]);Sourcepub fn set_invalid_row_count<T: Into<i64>>(self, v: T) -> Self
pub fn set_invalid_row_count<T: Into<i64>>(self, v: T) -> Self
Sets the value of invalid_row_count.
Example
let x = ImportFeatureValuesOperationMetadata::new().set_invalid_row_count(42);Sourcepub fn set_timestamp_outside_retention_rows_count<T: Into<i64>>(
self,
v: T,
) -> Self
pub fn set_timestamp_outside_retention_rows_count<T: Into<i64>>( self, v: T, ) -> Self
Sets the value of timestamp_outside_retention_rows_count.
Example
let x = ImportFeatureValuesOperationMetadata::new().set_timestamp_outside_retention_rows_count(42);Sourcepub fn set_blocking_operation_ids<T, V>(self, v: T) -> Self
pub fn set_blocking_operation_ids<T, V>(self, v: T) -> Self
Sets the value of blocking_operation_ids.
Example
let x = ImportFeatureValuesOperationMetadata::new().set_blocking_operation_ids([1, 2, 3]);Trait Implementations
Sourceimpl Clone for ImportFeatureValuesOperationMetadata
impl Clone for ImportFeatureValuesOperationMetadata
Sourcefn clone(&self) -> ImportFeatureValuesOperationMetadata
fn clone(&self) -> ImportFeatureValuesOperationMetadata
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for ImportFeatureValuesOperationMetadata
impl Default for ImportFeatureValuesOperationMetadata
Sourcefn default() -> ImportFeatureValuesOperationMetadata
fn default() -> ImportFeatureValuesOperationMetadata
impl StructuralPartialEq for ImportFeatureValuesOperationMetadata