IntegratedGradientsAttribution

Struct IntegratedGradientsAttribution 

#[non_exhaustive]
pub struct IntegratedGradientsAttribution { pub step_count: i32, pub smooth_grad_config: Option<SmoothGradConfig>, pub blur_baseline_config: Option<BlurBaselineConfig>, /* private fields */ }
Available on crate features dataset-service or deployment-resource-pool-service or endpoint-service or job-service or model-service or pipeline-service or prediction-service only.
An attribution method that computes the Aumann-Shapley value taking advantage of the model’s fully differentiable structure. Refer to this paper for more details: https://arxiv.org/abs/1703.01365

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
step_count: i32

Required. The number of steps for approximating the path integral. A good value to start is 50 and gradually increase until the sum to diff property is within the desired error range.

Valid range of its value is [1, 100], inclusively.

smooth_grad_config: Option<SmoothGradConfig>

Config for SmoothGrad approximation of gradients.

When enabled, the gradients are approximated by averaging the gradients from noisy samples in the vicinity of the inputs. Adding noise can help improve the computed gradients. Refer to this paper for more details: https://arxiv.org/pdf/1706.03825.pdf

blur_baseline_config: Option<BlurBaselineConfig>

Config for IG with blur baseline.

When enabled, a linear path from the maximally blurred image to the input image is created. Using a blurred baseline instead of zero (black image) is motivated by the BlurIG approach explained here: https://arxiv.org/abs/2004.03383

Implementations

Source

impl IntegratedGradientsAttribution

pub fn new() -> Self

pub fn set_step_count<T: Into<i32>>(self, v: T) -> Self

Sets the value of step_count.

Example
let x = IntegratedGradientsAttribution::new().set_step_count(42);
pub fn set_smooth_grad_config<T>(self, v: T) -> Self

Sets the value of smooth_grad_config.

Example
use google_cloud_aiplatform_v1::model::SmoothGradConfig;
let x = IntegratedGradientsAttribution::new().set_smooth_grad_config(SmoothGradConfig::default()/* use setters */);
pub fn set_or_clear_smooth_grad_config<T>(self, v: Option<T>) -> Self

Sets or clears the value of smooth_grad_config.

Example
use google_cloud_aiplatform_v1::model::SmoothGradConfig;
let x = IntegratedGradientsAttribution::new().set_or_clear_smooth_grad_config(Some(SmoothGradConfig::default()/* use setters */));
let x = IntegratedGradientsAttribution::new().set_or_clear_smooth_grad_config(None::<SmoothGradConfig>);
pub fn set_blur_baseline_config<T>(self, v: T) -> Self

Sets the value of blur_baseline_config.

Example
use google_cloud_aiplatform_v1::model::BlurBaselineConfig;
let x = IntegratedGradientsAttribution::new().set_blur_baseline_config(BlurBaselineConfig::default()/* use setters */);
pub fn set_or_clear_blur_baseline_config<T>(self, v: Option<T>) -> Self

Sets or clears the value of blur_baseline_config.

Example
use google_cloud_aiplatform_v1::model::BlurBaselineConfig;
let x = IntegratedGradientsAttribution::new().set_or_clear_blur_baseline_config(Some(BlurBaselineConfig::default()/* use setters */));
let x = IntegratedGradientsAttribution::new().set_or_clear_blur_baseline_config(None::<BlurBaselineConfig>);