#[non_exhaustive]pub struct ListSessionsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
pub order_by: String,
/* private fields */
}session-service only.Expand description
Request message for SessionService.ListSessions.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The resource name of the location to list sessions from.
Format:
projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}
page_size: i32Optional. The maximum number of sessions to return. The service may return fewer than this value. If unspecified, at most 100 sessions will be returned.
page_token: StringOptional. The next_page_token value returned from a previous list SessionService.ListSessions call.
filter: StringOptional. The standard list filter. Supported fields:
display_nameuser_idlabels
Example: display_name="abc", user_id="123", labels.key="value".
order_by: StringOptional. A comma-separated list of fields to order by, sorted in ascending order. Use “desc” after a field name for descending. Supported fields:
create_timeupdate_time
Example: create_time desc.
Implementations
Sourceimpl ListSessionsRequest
impl ListSessionsRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListSessionsRequest::new().set_page_token("example");Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self