#[non_exhaustive]pub struct MetadataStore {
pub name: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub encryption_spec: Option<EncryptionSpec>,
pub description: String,
pub state: Option<MetadataStoreState>,
pub dataplex_config: Option<DataplexConfig>,
/* private fields */
}metadata-service only.Expand description
Instance of a metadata store. Contains a set of metadata that can be queried.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The resource name of the MetadataStore instance.
create_time: Option<Timestamp>Output only. Timestamp when this MetadataStore was created.
update_time: Option<Timestamp>Output only. Timestamp when this MetadataStore was last updated.
encryption_spec: Option<EncryptionSpec>Customer-managed encryption key spec for a Metadata Store. If set, this Metadata Store and all sub-resources of this Metadata Store are secured using this key.
description: StringDescription of the MetadataStore.
state: Option<MetadataStoreState>Output only. State information of the MetadataStore.
dataplex_config: Option<DataplexConfig>Optional. Dataplex integration settings.
Implementations
Sourceimpl MetadataStore
impl MetadataStore
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = MetadataStore::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = MetadataStore::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = MetadataStore::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = MetadataStore::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = MetadataStore::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = MetadataStore::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_encryption_spec<T>(self, v: T) -> Selfwhere
T: Into<EncryptionSpec>,
pub fn set_encryption_spec<T>(self, v: T) -> Selfwhere
T: Into<EncryptionSpec>,
Sets the value of encryption_spec.
Example
use google_cloud_aiplatform_v1::model::EncryptionSpec;
let x = MetadataStore::new().set_encryption_spec(EncryptionSpec::default()/* use setters */);Sourcepub fn set_or_clear_encryption_spec<T>(self, v: Option<T>) -> Selfwhere
T: Into<EncryptionSpec>,
pub fn set_or_clear_encryption_spec<T>(self, v: Option<T>) -> Selfwhere
T: Into<EncryptionSpec>,
Sets or clears the value of encryption_spec.
Example
use google_cloud_aiplatform_v1::model::EncryptionSpec;
let x = MetadataStore::new().set_or_clear_encryption_spec(Some(EncryptionSpec::default()/* use setters */));
let x = MetadataStore::new().set_or_clear_encryption_spec(None::<EncryptionSpec>);Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_state<T>(self, v: T) -> Selfwhere
T: Into<MetadataStoreState>,
pub fn set_state<T>(self, v: T) -> Selfwhere
T: Into<MetadataStoreState>,
Sourcepub fn set_or_clear_state<T>(self, v: Option<T>) -> Selfwhere
T: Into<MetadataStoreState>,
pub fn set_or_clear_state<T>(self, v: Option<T>) -> Selfwhere
T: Into<MetadataStoreState>,
Sourcepub fn set_dataplex_config<T>(self, v: T) -> Selfwhere
T: Into<DataplexConfig>,
pub fn set_dataplex_config<T>(self, v: T) -> Selfwhere
T: Into<DataplexConfig>,
Sets the value of dataplex_config.
Example
use google_cloud_aiplatform_v1::model::metadata_store::DataplexConfig;
let x = MetadataStore::new().set_dataplex_config(DataplexConfig::default()/* use setters */);Sourcepub fn set_or_clear_dataplex_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<DataplexConfig>,
pub fn set_or_clear_dataplex_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<DataplexConfig>,
Sets or clears the value of dataplex_config.
Example
use google_cloud_aiplatform_v1::model::metadata_store::DataplexConfig;
let x = MetadataStore::new().set_or_clear_dataplex_config(Some(DataplexConfig::default()/* use setters */));
let x = MetadataStore::new().set_or_clear_dataplex_config(None::<DataplexConfig>);Trait Implementations
Sourceimpl Clone for MetadataStore
impl Clone for MetadataStore
Sourcefn clone(&self) -> MetadataStore
fn clone(&self) -> MetadataStore
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for MetadataStore
impl Debug for MetadataStore
Sourceimpl Default for MetadataStore
impl Default for MetadataStore
Sourcefn default() -> MetadataStore
fn default() -> MetadataStore
Sourceimpl Message for MetadataStore
impl Message for MetadataStore
Sourceimpl PartialEq for MetadataStore
impl PartialEq for MetadataStore
impl StructuralPartialEq for MetadataStore