#[non_exhaustive]pub struct ModelMonitoringObjectiveConfig {
pub training_dataset: Option<TrainingDataset>,
pub training_prediction_skew_detection_config: Option<TrainingPredictionSkewDetectionConfig>,
pub prediction_drift_detection_config: Option<PredictionDriftDetectionConfig>,
pub explanation_config: Option<ExplanationConfig>,
/* private fields */
}job-service only.Expand description
The objective configuration for model monitoring, including the information needed to detect anomalies for one particular model.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.training_dataset: Option<TrainingDataset>Training dataset for models. This field has to be set only if TrainingPredictionSkewDetectionConfig is specified.
training_prediction_skew_detection_config: Option<TrainingPredictionSkewDetectionConfig>The config for skew between training data and prediction data.
prediction_drift_detection_config: Option<PredictionDriftDetectionConfig>The config for drift of prediction data.
explanation_config: Option<ExplanationConfig>The config for integrating with Vertex Explainable AI.
Implementations
Sourceimpl ModelMonitoringObjectiveConfig
impl ModelMonitoringObjectiveConfig
Sourcepub fn set_training_dataset<T>(self, v: T) -> Selfwhere
T: Into<TrainingDataset>,
pub fn set_training_dataset<T>(self, v: T) -> Selfwhere
T: Into<TrainingDataset>,
Sets the value of training_dataset.
Example
use google_cloud_aiplatform_v1::model::model_monitoring_objective_config::TrainingDataset;
let x = ModelMonitoringObjectiveConfig::new().set_training_dataset(TrainingDataset::default()/* use setters */);Sourcepub fn set_or_clear_training_dataset<T>(self, v: Option<T>) -> Selfwhere
T: Into<TrainingDataset>,
pub fn set_or_clear_training_dataset<T>(self, v: Option<T>) -> Selfwhere
T: Into<TrainingDataset>,
Sets or clears the value of training_dataset.
Example
use google_cloud_aiplatform_v1::model::model_monitoring_objective_config::TrainingDataset;
let x = ModelMonitoringObjectiveConfig::new().set_or_clear_training_dataset(Some(TrainingDataset::default()/* use setters */));
let x = ModelMonitoringObjectiveConfig::new().set_or_clear_training_dataset(None::<TrainingDataset>);Sourcepub fn set_training_prediction_skew_detection_config<T>(self, v: T) -> Selfwhere
T: Into<TrainingPredictionSkewDetectionConfig>,
pub fn set_training_prediction_skew_detection_config<T>(self, v: T) -> Selfwhere
T: Into<TrainingPredictionSkewDetectionConfig>,
Sets the value of training_prediction_skew_detection_config.
Example
use google_cloud_aiplatform_v1::model::model_monitoring_objective_config::TrainingPredictionSkewDetectionConfig;
let x = ModelMonitoringObjectiveConfig::new().set_training_prediction_skew_detection_config(TrainingPredictionSkewDetectionConfig::default()/* use setters */);Sourcepub fn set_or_clear_training_prediction_skew_detection_config<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<TrainingPredictionSkewDetectionConfig>,
pub fn set_or_clear_training_prediction_skew_detection_config<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<TrainingPredictionSkewDetectionConfig>,
Sets or clears the value of training_prediction_skew_detection_config.
Example
use google_cloud_aiplatform_v1::model::model_monitoring_objective_config::TrainingPredictionSkewDetectionConfig;
let x = ModelMonitoringObjectiveConfig::new().set_or_clear_training_prediction_skew_detection_config(Some(TrainingPredictionSkewDetectionConfig::default()/* use setters */));
let x = ModelMonitoringObjectiveConfig::new().set_or_clear_training_prediction_skew_detection_config(None::<TrainingPredictionSkewDetectionConfig>);Sourcepub fn set_prediction_drift_detection_config<T>(self, v: T) -> Selfwhere
T: Into<PredictionDriftDetectionConfig>,
pub fn set_prediction_drift_detection_config<T>(self, v: T) -> Selfwhere
T: Into<PredictionDriftDetectionConfig>,
Sets the value of prediction_drift_detection_config.
Example
use google_cloud_aiplatform_v1::model::model_monitoring_objective_config::PredictionDriftDetectionConfig;
let x = ModelMonitoringObjectiveConfig::new().set_prediction_drift_detection_config(PredictionDriftDetectionConfig::default()/* use setters */);Sourcepub fn set_or_clear_prediction_drift_detection_config<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<PredictionDriftDetectionConfig>,
pub fn set_or_clear_prediction_drift_detection_config<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<PredictionDriftDetectionConfig>,
Sets or clears the value of prediction_drift_detection_config.
Example
use google_cloud_aiplatform_v1::model::model_monitoring_objective_config::PredictionDriftDetectionConfig;
let x = ModelMonitoringObjectiveConfig::new().set_or_clear_prediction_drift_detection_config(Some(PredictionDriftDetectionConfig::default()/* use setters */));
let x = ModelMonitoringObjectiveConfig::new().set_or_clear_prediction_drift_detection_config(None::<PredictionDriftDetectionConfig>);Sourcepub fn set_explanation_config<T>(self, v: T) -> Selfwhere
T: Into<ExplanationConfig>,
pub fn set_explanation_config<T>(self, v: T) -> Selfwhere
T: Into<ExplanationConfig>,
Sets the value of explanation_config.
Example
use google_cloud_aiplatform_v1::model::model_monitoring_objective_config::ExplanationConfig;
let x = ModelMonitoringObjectiveConfig::new().set_explanation_config(ExplanationConfig::default()/* use setters */);Sourcepub fn set_or_clear_explanation_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<ExplanationConfig>,
pub fn set_or_clear_explanation_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<ExplanationConfig>,
Sets or clears the value of explanation_config.
Example
use google_cloud_aiplatform_v1::model::model_monitoring_objective_config::ExplanationConfig;
let x = ModelMonitoringObjectiveConfig::new().set_or_clear_explanation_config(Some(ExplanationConfig::default()/* use setters */));
let x = ModelMonitoringObjectiveConfig::new().set_or_clear_explanation_config(None::<ExplanationConfig>);Trait Implementations
Sourceimpl Clone for ModelMonitoringObjectiveConfig
impl Clone for ModelMonitoringObjectiveConfig
Sourcefn clone(&self) -> ModelMonitoringObjectiveConfig
fn clone(&self) -> ModelMonitoringObjectiveConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for ModelMonitoringObjectiveConfig
impl Default for ModelMonitoringObjectiveConfig
Sourcefn default() -> ModelMonitoringObjectiveConfig
fn default() -> ModelMonitoringObjectiveConfig
impl StructuralPartialEq for ModelMonitoringObjectiveConfig