#[non_exhaustive]pub struct NotebookEucConfig {
pub euc_disabled: bool,
pub bypass_actas_check: bool,
/* private fields */
}notebook-service only.Expand description
The euc configuration of NotebookRuntimeTemplate.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.euc_disabled: boolInput only. Whether EUC is disabled in this NotebookRuntimeTemplate. In proto3, the default value of a boolean is false. In this way, by default EUC will be enabled for NotebookRuntimeTemplate.
bypass_actas_check: boolOutput only. Whether ActAs check is bypassed for service account attached to the VM. If false, we need ActAs check for the default Compute Engine Service account. When a Runtime is created, a VM is allocated using Default Compute Engine Service Account. Any user requesting to use this Runtime requires Service Account User (ActAs) permission over this SA. If true, Runtime owner is using EUC and does not require the above permission as VM no longer use default Compute Engine SA, but a P4SA.
Implementations
Sourceimpl NotebookEucConfig
impl NotebookEucConfig
Sourcepub fn set_euc_disabled<T: Into<bool>>(self, v: T) -> Self
pub fn set_euc_disabled<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_bypass_actas_check<T: Into<bool>>(self, v: T) -> Self
pub fn set_bypass_actas_check<T: Into<bool>>(self, v: T) -> Self
Sets the value of bypass_actas_check.
Example
let x = NotebookEucConfig::new().set_bypass_actas_check(true);Trait Implementations
Sourceimpl Clone for NotebookEucConfig
impl Clone for NotebookEucConfig
Sourcefn clone(&self) -> NotebookEucConfig
fn clone(&self) -> NotebookEucConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for NotebookEucConfig
impl Debug for NotebookEucConfig
Sourceimpl Default for NotebookEucConfig
impl Default for NotebookEucConfig
Sourcefn default() -> NotebookEucConfig
fn default() -> NotebookEucConfig
Sourceimpl Message for NotebookEucConfig
impl Message for NotebookEucConfig
Sourceimpl PartialEq for NotebookEucConfig
impl PartialEq for NotebookEucConfig
impl StructuralPartialEq for NotebookEucConfig