#[non_exhaustive]pub struct OutputInfo {
pub output_location: Option<OutputLocation>,
/* private fields */
}Available on crate feature
gen-ai-tuning-service only.Expand description
Describes the info for output of EvaluationService.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.output_location: Option<OutputLocation>The output location into which evaluation output is written.
Implementations
Sourceimpl OutputInfo
impl OutputInfo
pub fn new() -> Self
Sourcepub fn set_output_location<T: Into<Option<OutputLocation>>>(self, v: T) -> Self
pub fn set_output_location<T: Into<Option<OutputLocation>>>(self, v: T) -> Self
Sets the value of output_location.
Note that all the setters affecting output_location are mutually
exclusive.
Example
ⓘ
use google_cloud_aiplatform_v1::model::output_info::OutputLocation;
let x = OutputInfo::new().set_output_location(Some(OutputLocation::GcsOutputDirectory("example".to_string())));Sourcepub fn gcs_output_directory(&self) -> Option<&String>
pub fn gcs_output_directory(&self) -> Option<&String>
The value of output_location
if it holds a GcsOutputDirectory, None if the field is not set or
holds a different branch.
Sourcepub fn set_gcs_output_directory<T: Into<String>>(self, v: T) -> Self
pub fn set_gcs_output_directory<T: Into<String>>(self, v: T) -> Self
Sets the value of output_location
to hold a GcsOutputDirectory.
Note that all the setters affecting output_location are
mutually exclusive.
Example
ⓘ
let x = OutputInfo::new().set_gcs_output_directory("example");
assert!(x.gcs_output_directory().is_some());Trait Implementations
Sourceimpl Clone for OutputInfo
impl Clone for OutputInfo
Sourcefn clone(&self) -> OutputInfo
fn clone(&self) -> OutputInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OutputInfo
impl Debug for OutputInfo
Sourceimpl Default for OutputInfo
impl Default for OutputInfo
Sourcefn default() -> OutputInfo
fn default() -> OutputInfo
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for OutputInfo
impl PartialEq for OutputInfo
impl StructuralPartialEq for OutputInfo