#[non_exhaustive]pub struct Part {
pub thought: bool,
pub thought_signature: Bytes,
pub media_resolution: Option<MediaResolution>,
pub data: Option<Data>,
pub metadata: Option<Metadata>,
/* private fields */
}data-foundry-service or evaluation-service or gen-ai-cache-service or gen-ai-tuning-service or llm-utility-service or prediction-service or session-service or vertex-rag-service only.Expand description
A datatype containing media that is part of a multi-part Content message.
A Part consists of data which has an associated datatype. A Part can only
contain one of the accepted types in Part.data.
A Part must have a fixed IANA MIME type identifying the type and subtype
of the media if inline_data or file_data field is filled with raw bytes.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.thought: boolIndicates if the part is thought from the model.
thought_signature: BytesAn opaque signature for the thought so it can be reused in subsequent requests.
media_resolution: Option<MediaResolution>per part media resolution. Media resolution for the input media.
data: Option<Data>metadata: Option<Metadata>Implementations
Sourceimpl Part
impl Part
Sourcepub fn set_thought<T: Into<bool>>(self, v: T) -> Self
pub fn set_thought<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_thought_signature<T: Into<Bytes>>(self, v: T) -> Self
pub fn set_thought_signature<T: Into<Bytes>>(self, v: T) -> Self
Sets the value of thought_signature.
Example
let x = Part::new().set_thought_signature(bytes::Bytes::from_static(b"example"));Sourcepub fn set_media_resolution<T>(self, v: T) -> Selfwhere
T: Into<MediaResolution>,
pub fn set_media_resolution<T>(self, v: T) -> Selfwhere
T: Into<MediaResolution>,
Sets the value of media_resolution.
Example
use google_cloud_aiplatform_v1::model::part::MediaResolution;
let x = Part::new().set_media_resolution(MediaResolution::default()/* use setters */);Sourcepub fn set_or_clear_media_resolution<T>(self, v: Option<T>) -> Selfwhere
T: Into<MediaResolution>,
pub fn set_or_clear_media_resolution<T>(self, v: Option<T>) -> Selfwhere
T: Into<MediaResolution>,
Sets or clears the value of media_resolution.
Example
use google_cloud_aiplatform_v1::model::part::MediaResolution;
let x = Part::new().set_or_clear_media_resolution(Some(MediaResolution::default()/* use setters */));
let x = Part::new().set_or_clear_media_resolution(None::<MediaResolution>);Sourcepub fn text(&self) -> Option<&String>
pub fn text(&self) -> Option<&String>
The value of data
if it holds a Text, None if the field is not set or
holds a different branch.
Sourcepub fn set_text<T: Into<String>>(self, v: T) -> Self
pub fn set_text<T: Into<String>>(self, v: T) -> Self
Sets the value of data
to hold a Text.
Note that all the setters affecting data are
mutually exclusive.
Example
let x = Part::new().set_text("example");
assert!(x.text().is_some());
assert!(x.inline_data().is_none());
assert!(x.file_data().is_none());
assert!(x.function_call().is_none());
assert!(x.function_response().is_none());
assert!(x.executable_code().is_none());
assert!(x.code_execution_result().is_none());Sourcepub fn inline_data(&self) -> Option<&Box<Blob>>
pub fn inline_data(&self) -> Option<&Box<Blob>>
The value of data
if it holds a InlineData, None if the field is not set or
holds a different branch.
Sourcepub fn set_inline_data<T: Into<Box<Blob>>>(self, v: T) -> Self
pub fn set_inline_data<T: Into<Box<Blob>>>(self, v: T) -> Self
Sets the value of data
to hold a InlineData.
Note that all the setters affecting data are
mutually exclusive.
Example
use google_cloud_aiplatform_v1::model::Blob;
let x = Part::new().set_inline_data(Blob::default()/* use setters */);
assert!(x.inline_data().is_some());
assert!(x.text().is_none());
assert!(x.file_data().is_none());
assert!(x.function_call().is_none());
assert!(x.function_response().is_none());
assert!(x.executable_code().is_none());
assert!(x.code_execution_result().is_none());Sourcepub fn file_data(&self) -> Option<&Box<FileData>>
pub fn file_data(&self) -> Option<&Box<FileData>>
The value of data
if it holds a FileData, None if the field is not set or
holds a different branch.
Sourcepub fn set_file_data<T: Into<Box<FileData>>>(self, v: T) -> Self
pub fn set_file_data<T: Into<Box<FileData>>>(self, v: T) -> Self
Sets the value of data
to hold a FileData.
Note that all the setters affecting data are
mutually exclusive.
Example
use google_cloud_aiplatform_v1::model::FileData;
let x = Part::new().set_file_data(FileData::default()/* use setters */);
assert!(x.file_data().is_some());
assert!(x.text().is_none());
assert!(x.inline_data().is_none());
assert!(x.function_call().is_none());
assert!(x.function_response().is_none());
assert!(x.executable_code().is_none());
assert!(x.code_execution_result().is_none());Sourcepub fn function_call(&self) -> Option<&Box<FunctionCall>>
pub fn function_call(&self) -> Option<&Box<FunctionCall>>
The value of data
if it holds a FunctionCall, None if the field is not set or
holds a different branch.
Sourcepub fn set_function_call<T: Into<Box<FunctionCall>>>(self, v: T) -> Self
pub fn set_function_call<T: Into<Box<FunctionCall>>>(self, v: T) -> Self
Sets the value of data
to hold a FunctionCall.
Note that all the setters affecting data are
mutually exclusive.
Example
use google_cloud_aiplatform_v1::model::FunctionCall;
let x = Part::new().set_function_call(FunctionCall::default()/* use setters */);
assert!(x.function_call().is_some());
assert!(x.text().is_none());
assert!(x.inline_data().is_none());
assert!(x.file_data().is_none());
assert!(x.function_response().is_none());
assert!(x.executable_code().is_none());
assert!(x.code_execution_result().is_none());Sourcepub fn function_response(&self) -> Option<&Box<FunctionResponse>>
pub fn function_response(&self) -> Option<&Box<FunctionResponse>>
The value of data
if it holds a FunctionResponse, None if the field is not set or
holds a different branch.
Sourcepub fn set_function_response<T: Into<Box<FunctionResponse>>>(self, v: T) -> Self
pub fn set_function_response<T: Into<Box<FunctionResponse>>>(self, v: T) -> Self
Sets the value of data
to hold a FunctionResponse.
Note that all the setters affecting data are
mutually exclusive.
Example
use google_cloud_aiplatform_v1::model::FunctionResponse;
let x = Part::new().set_function_response(FunctionResponse::default()/* use setters */);
assert!(x.function_response().is_some());
assert!(x.text().is_none());
assert!(x.inline_data().is_none());
assert!(x.file_data().is_none());
assert!(x.function_call().is_none());
assert!(x.executable_code().is_none());
assert!(x.code_execution_result().is_none());Sourcepub fn executable_code(&self) -> Option<&Box<ExecutableCode>>
pub fn executable_code(&self) -> Option<&Box<ExecutableCode>>
The value of data
if it holds a ExecutableCode, None if the field is not set or
holds a different branch.
Sourcepub fn set_executable_code<T: Into<Box<ExecutableCode>>>(self, v: T) -> Self
pub fn set_executable_code<T: Into<Box<ExecutableCode>>>(self, v: T) -> Self
Sets the value of data
to hold a ExecutableCode.
Note that all the setters affecting data are
mutually exclusive.
Example
use google_cloud_aiplatform_v1::model::ExecutableCode;
let x = Part::new().set_executable_code(ExecutableCode::default()/* use setters */);
assert!(x.executable_code().is_some());
assert!(x.text().is_none());
assert!(x.inline_data().is_none());
assert!(x.file_data().is_none());
assert!(x.function_call().is_none());
assert!(x.function_response().is_none());
assert!(x.code_execution_result().is_none());Sourcepub fn code_execution_result(&self) -> Option<&Box<CodeExecutionResult>>
pub fn code_execution_result(&self) -> Option<&Box<CodeExecutionResult>>
The value of data
if it holds a CodeExecutionResult, None if the field is not set or
holds a different branch.
Sourcepub fn set_code_execution_result<T: Into<Box<CodeExecutionResult>>>(
self,
v: T,
) -> Self
pub fn set_code_execution_result<T: Into<Box<CodeExecutionResult>>>( self, v: T, ) -> Self
Sets the value of data
to hold a CodeExecutionResult.
Note that all the setters affecting data are
mutually exclusive.
Example
use google_cloud_aiplatform_v1::model::CodeExecutionResult;
let x = Part::new().set_code_execution_result(CodeExecutionResult::default()/* use setters */);
assert!(x.code_execution_result().is_some());
assert!(x.text().is_none());
assert!(x.inline_data().is_none());
assert!(x.file_data().is_none());
assert!(x.function_call().is_none());
assert!(x.function_response().is_none());
assert!(x.executable_code().is_none());Sourcepub fn set_metadata<T: Into<Option<Metadata>>>(self, v: T) -> Self
pub fn set_metadata<T: Into<Option<Metadata>>>(self, v: T) -> Self
Sets the value of metadata.
Note that all the setters affecting metadata are mutually
exclusive.
Example
use google_cloud_aiplatform_v1::model::VideoMetadata;
let x = Part::new().set_metadata(Some(
google_cloud_aiplatform_v1::model::part::Metadata::VideoMetadata(VideoMetadata::default().into())));Sourcepub fn video_metadata(&self) -> Option<&Box<VideoMetadata>>
pub fn video_metadata(&self) -> Option<&Box<VideoMetadata>>
The value of metadata
if it holds a VideoMetadata, None if the field is not set or
holds a different branch.
Sourcepub fn set_video_metadata<T: Into<Box<VideoMetadata>>>(self, v: T) -> Self
pub fn set_video_metadata<T: Into<Box<VideoMetadata>>>(self, v: T) -> Self
Sets the value of metadata
to hold a VideoMetadata.
Note that all the setters affecting metadata are
mutually exclusive.
Example
use google_cloud_aiplatform_v1::model::VideoMetadata;
let x = Part::new().set_video_metadata(VideoMetadata::default()/* use setters */);
assert!(x.video_metadata().is_some());Trait Implementations
impl StructuralPartialEq for Part