#[non_exhaustive]pub struct PredictResponse {
pub predictions: Vec<Value>,
pub deployed_model_id: String,
pub model: String,
pub model_version_id: String,
pub model_display_name: String,
pub metadata: Option<Value>,
/* private fields */
}prediction-service only.Expand description
Response message for PredictionService.Predict.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.predictions: Vec<Value>The predictions that are the output of the predictions call. The schema of any single prediction may be specified via Endpoint’s DeployedModels’ Model’s PredictSchemata’s prediction_schema_uri.
deployed_model_id: StringID of the Endpoint’s DeployedModel that served this prediction.
model: StringOutput only. The resource name of the Model which is deployed as the DeployedModel that this prediction hits.
model_version_id: StringOutput only. The version ID of the Model which is deployed as the DeployedModel that this prediction hits.
model_display_name: StringOutput only. The display name of the Model which is deployed as the DeployedModel that this prediction hits.
metadata: Option<Value>Output only. Request-level metadata returned by the model. The metadata type will be dependent upon the model implementation.
Implementations
Sourceimpl PredictResponse
impl PredictResponse
Sourcepub fn set_predictions<T, V>(self, v: T) -> Self
pub fn set_predictions<T, V>(self, v: T) -> Self
Sets the value of predictions.
Example
use wkt::Value;
let x = PredictResponse::new()
.set_predictions([
Value::default()/* use setters */,
Value::default()/* use (different) setters */,
]);Sourcepub fn set_deployed_model_id<T: Into<String>>(self, v: T) -> Self
pub fn set_deployed_model_id<T: Into<String>>(self, v: T) -> Self
Sets the value of deployed_model_id.
Example
let x = PredictResponse::new().set_deployed_model_id("example");Sourcepub fn set_model_version_id<T: Into<String>>(self, v: T) -> Self
pub fn set_model_version_id<T: Into<String>>(self, v: T) -> Self
Sets the value of model_version_id.
Example
let x = PredictResponse::new().set_model_version_id("example");Sourcepub fn set_model_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_model_display_name<T: Into<String>>(self, v: T) -> Self
Sets the value of model_display_name.
Example
let x = PredictResponse::new().set_model_display_name("example");Sourcepub fn set_metadata<T>(self, v: T) -> Self
pub fn set_metadata<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_metadata<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_metadata<T>(self, v: Option<T>) -> Self