Presets

Struct Presets 

#[non_exhaustive]
pub struct Presets { pub query: Option<Query>, pub modality: Modality, /* private fields */ }
Available on crate features dataset-service or deployment-resource-pool-service or endpoint-service or job-service or model-service or pipeline-service or prediction-service only.
Preset configuration for example-based explanations

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
query: Option<Query>

Preset option controlling parameters for speed-precision trade-off when querying for examples. If omitted, defaults to PRECISE.

modality: Modality

The modality of the uploaded model, which automatically configures the distance measurement and feature normalization for the underlying example index and queries. If your model does not precisely fit one of these types, it is okay to choose the closest type.

Implementations

Source

impl Presets

pub fn new() -> Self

Creates a new default instance.

pub fn set_query<T>(self, v: T) -> Self
where T: Into<Query>,

Sets the value of query.

Example
use google_cloud_aiplatform_v1::model::presets::Query;
let x0 = Presets::new().set_query(Query::Fast);
pub fn set_or_clear_query<T>(self, v: Option<T>) -> Self
where T: Into<Query>,

Sets or clears the value of query.

Example
use google_cloud_aiplatform_v1::model::presets::Query;
let x0 = Presets::new().set_or_clear_query(Some(Query::Fast));
let x_none = Presets::new().set_or_clear_query(None::<Query>);
pub fn set_modality<T: Into<Modality>>(self, v: T) -> Self

Sets the value of modality.

Example
use google_cloud_aiplatform_v1::model::presets::Modality;
let x0 = Presets::new().set_modality(Modality::Image);
let x1 = Presets::new().set_modality(Modality::Text);
let x2 = Presets::new().set_modality(Modality::Tabular);