#[non_exhaustive]pub struct ReasoningEngine {
pub name: String,
pub display_name: String,
pub description: String,
pub spec: Option<ReasoningEngineSpec>,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub etag: String,
pub encryption_spec: Option<EncryptionSpec>,
pub labels: HashMap<String, String>,
/* private fields */
}reasoning-engine-service only.Expand description
ReasoningEngine provides a customizable runtime for models to determine which actions to take and in which order.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The resource name of the ReasoningEngine.
Format:
projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}
display_name: StringRequired. The display name of the ReasoningEngine.
description: StringOptional. The description of the ReasoningEngine.
spec: Option<ReasoningEngineSpec>Optional. Configurations of the ReasoningEngine
create_time: Option<Timestamp>Output only. Timestamp when this ReasoningEngine was created.
update_time: Option<Timestamp>Output only. Timestamp when this ReasoningEngine was most recently updated.
etag: StringOptional. Used to perform consistent read-modify-write updates. If not set, a blind “overwrite” update happens.
encryption_spec: Option<EncryptionSpec>Customer-managed encryption key spec for a ReasoningEngine. If set, this ReasoningEngine and all sub-resources of this ReasoningEngine will be secured by this key.
labels: HashMap<String, String>Labels for the ReasoningEngine.
Implementations
Sourceimpl ReasoningEngine
impl ReasoningEngine
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sets the value of display_name.
Example
let x = ReasoningEngine::new().set_display_name("example");Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_spec<T>(self, v: T) -> Selfwhere
T: Into<ReasoningEngineSpec>,
pub fn set_spec<T>(self, v: T) -> Selfwhere
T: Into<ReasoningEngineSpec>,
Sourcepub fn set_or_clear_spec<T>(self, v: Option<T>) -> Selfwhere
T: Into<ReasoningEngineSpec>,
pub fn set_or_clear_spec<T>(self, v: Option<T>) -> Selfwhere
T: Into<ReasoningEngineSpec>,
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = ReasoningEngine::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = ReasoningEngine::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = ReasoningEngine::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = ReasoningEngine::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = ReasoningEngine::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = ReasoningEngine::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_encryption_spec<T>(self, v: T) -> Selfwhere
T: Into<EncryptionSpec>,
pub fn set_encryption_spec<T>(self, v: T) -> Selfwhere
T: Into<EncryptionSpec>,
Sets the value of encryption_spec.
Example
use google_cloud_aiplatform_v1::model::EncryptionSpec;
let x = ReasoningEngine::new().set_encryption_spec(EncryptionSpec::default()/* use setters */);Sourcepub fn set_or_clear_encryption_spec<T>(self, v: Option<T>) -> Selfwhere
T: Into<EncryptionSpec>,
pub fn set_or_clear_encryption_spec<T>(self, v: Option<T>) -> Selfwhere
T: Into<EncryptionSpec>,
Sets or clears the value of encryption_spec.
Example
use google_cloud_aiplatform_v1::model::EncryptionSpec;
let x = ReasoningEngine::new().set_or_clear_encryption_spec(Some(EncryptionSpec::default()/* use setters */));
let x = ReasoningEngine::new().set_or_clear_encryption_spec(None::<EncryptionSpec>);Trait Implementations
Sourceimpl Clone for ReasoningEngine
impl Clone for ReasoningEngine
Sourcefn clone(&self) -> ReasoningEngine
fn clone(&self) -> ReasoningEngine
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ReasoningEngine
impl Debug for ReasoningEngine
Sourceimpl Default for ReasoningEngine
impl Default for ReasoningEngine
Sourcefn default() -> ReasoningEngine
fn default() -> ReasoningEngine
Sourceimpl Message for ReasoningEngine
impl Message for ReasoningEngine
Sourceimpl PartialEq for ReasoningEngine
impl PartialEq for ReasoningEngine
impl StructuralPartialEq for ReasoningEngine