#[non_exhaustive]pub struct SupervisedTuningDataStats {
pub tuning_dataset_example_count: i64,
pub total_tuning_character_count: i64,
pub total_billable_character_count: i64,
pub total_billable_token_count: i64,
pub tuning_step_count: i64,
pub user_input_token_distribution: Option<SupervisedTuningDatasetDistribution>,
pub user_output_token_distribution: Option<SupervisedTuningDatasetDistribution>,
pub user_message_per_example_distribution: Option<SupervisedTuningDatasetDistribution>,
pub user_dataset_examples: Vec<Content>,
pub total_truncated_example_count: i64,
pub truncated_example_indices: Vec<i64>,
pub dropped_example_reasons: Vec<String>,
/* private fields */
}gen-ai-tuning-service only.Expand description
Tuning data statistics for Supervised Tuning.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.tuning_dataset_example_count: i64Output only. Number of examples in the tuning dataset.
total_tuning_character_count: i64Output only. Number of tuning characters in the tuning dataset.
total_billable_character_count: i64Output only. Number of billable characters in the tuning dataset.
total_billable_token_count: i64Output only. Number of billable tokens in the tuning dataset.
tuning_step_count: i64Output only. Number of tuning steps for this Tuning Job.
user_input_token_distribution: Option<SupervisedTuningDatasetDistribution>Output only. Dataset distributions for the user input tokens.
user_output_token_distribution: Option<SupervisedTuningDatasetDistribution>Output only. Dataset distributions for the user output tokens.
user_message_per_example_distribution: Option<SupervisedTuningDatasetDistribution>Output only. Dataset distributions for the messages per example.
user_dataset_examples: Vec<Content>Output only. Sample user messages in the training dataset uri.
total_truncated_example_count: i64Output only. The number of examples in the dataset that have been dropped. An example can be dropped for reasons including: too many tokens, contains an invalid image, contains too many images, etc.
truncated_example_indices: Vec<i64>Output only. A partial sample of the indices (starting from 1) of the dropped examples.
dropped_example_reasons: Vec<String>Output only. For each index in truncated_example_indices, the user-facing
reason why the example was dropped.
Implementations
Sourceimpl SupervisedTuningDataStats
impl SupervisedTuningDataStats
Sourcepub fn set_tuning_dataset_example_count<T: Into<i64>>(self, v: T) -> Self
pub fn set_tuning_dataset_example_count<T: Into<i64>>(self, v: T) -> Self
Sets the value of tuning_dataset_example_count.
Example
let x = SupervisedTuningDataStats::new().set_tuning_dataset_example_count(42);Sourcepub fn set_total_tuning_character_count<T: Into<i64>>(self, v: T) -> Self
pub fn set_total_tuning_character_count<T: Into<i64>>(self, v: T) -> Self
Sets the value of total_tuning_character_count.
Example
let x = SupervisedTuningDataStats::new().set_total_tuning_character_count(42);Sourcepub fn set_total_billable_character_count<T: Into<i64>>(self, v: T) -> Self
👎Deprecated
pub fn set_total_billable_character_count<T: Into<i64>>(self, v: T) -> Self
Sets the value of total_billable_character_count.
Example
let x = SupervisedTuningDataStats::new().set_total_billable_character_count(42);Sourcepub fn set_total_billable_token_count<T: Into<i64>>(self, v: T) -> Self
pub fn set_total_billable_token_count<T: Into<i64>>(self, v: T) -> Self
Sets the value of total_billable_token_count.
Example
let x = SupervisedTuningDataStats::new().set_total_billable_token_count(42);Sourcepub fn set_tuning_step_count<T: Into<i64>>(self, v: T) -> Self
pub fn set_tuning_step_count<T: Into<i64>>(self, v: T) -> Self
Sets the value of tuning_step_count.
Example
let x = SupervisedTuningDataStats::new().set_tuning_step_count(42);Sourcepub fn set_user_input_token_distribution<T>(self, v: T) -> Selfwhere
T: Into<SupervisedTuningDatasetDistribution>,
pub fn set_user_input_token_distribution<T>(self, v: T) -> Selfwhere
T: Into<SupervisedTuningDatasetDistribution>,
Sets the value of user_input_token_distribution.
Example
use google_cloud_aiplatform_v1::model::SupervisedTuningDatasetDistribution;
let x = SupervisedTuningDataStats::new().set_user_input_token_distribution(SupervisedTuningDatasetDistribution::default()/* use setters */);Sourcepub fn set_or_clear_user_input_token_distribution<T>(self, v: Option<T>) -> Selfwhere
T: Into<SupervisedTuningDatasetDistribution>,
pub fn set_or_clear_user_input_token_distribution<T>(self, v: Option<T>) -> Selfwhere
T: Into<SupervisedTuningDatasetDistribution>,
Sets or clears the value of user_input_token_distribution.
Example
use google_cloud_aiplatform_v1::model::SupervisedTuningDatasetDistribution;
let x = SupervisedTuningDataStats::new().set_or_clear_user_input_token_distribution(Some(SupervisedTuningDatasetDistribution::default()/* use setters */));
let x = SupervisedTuningDataStats::new().set_or_clear_user_input_token_distribution(None::<SupervisedTuningDatasetDistribution>);Sourcepub fn set_user_output_token_distribution<T>(self, v: T) -> Selfwhere
T: Into<SupervisedTuningDatasetDistribution>,
pub fn set_user_output_token_distribution<T>(self, v: T) -> Selfwhere
T: Into<SupervisedTuningDatasetDistribution>,
Sets the value of user_output_token_distribution.
Example
use google_cloud_aiplatform_v1::model::SupervisedTuningDatasetDistribution;
let x = SupervisedTuningDataStats::new().set_user_output_token_distribution(SupervisedTuningDatasetDistribution::default()/* use setters */);Sourcepub fn set_or_clear_user_output_token_distribution<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<SupervisedTuningDatasetDistribution>,
pub fn set_or_clear_user_output_token_distribution<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<SupervisedTuningDatasetDistribution>,
Sets or clears the value of user_output_token_distribution.
Example
use google_cloud_aiplatform_v1::model::SupervisedTuningDatasetDistribution;
let x = SupervisedTuningDataStats::new().set_or_clear_user_output_token_distribution(Some(SupervisedTuningDatasetDistribution::default()/* use setters */));
let x = SupervisedTuningDataStats::new().set_or_clear_user_output_token_distribution(None::<SupervisedTuningDatasetDistribution>);Sourcepub fn set_user_message_per_example_distribution<T>(self, v: T) -> Selfwhere
T: Into<SupervisedTuningDatasetDistribution>,
pub fn set_user_message_per_example_distribution<T>(self, v: T) -> Selfwhere
T: Into<SupervisedTuningDatasetDistribution>,
Sets the value of user_message_per_example_distribution.
Example
use google_cloud_aiplatform_v1::model::SupervisedTuningDatasetDistribution;
let x = SupervisedTuningDataStats::new().set_user_message_per_example_distribution(SupervisedTuningDatasetDistribution::default()/* use setters */);Sourcepub fn set_or_clear_user_message_per_example_distribution<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<SupervisedTuningDatasetDistribution>,
pub fn set_or_clear_user_message_per_example_distribution<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<SupervisedTuningDatasetDistribution>,
Sets or clears the value of user_message_per_example_distribution.
Example
use google_cloud_aiplatform_v1::model::SupervisedTuningDatasetDistribution;
let x = SupervisedTuningDataStats::new().set_or_clear_user_message_per_example_distribution(Some(SupervisedTuningDatasetDistribution::default()/* use setters */));
let x = SupervisedTuningDataStats::new().set_or_clear_user_message_per_example_distribution(None::<SupervisedTuningDatasetDistribution>);Sourcepub fn set_user_dataset_examples<T, V>(self, v: T) -> Self
pub fn set_user_dataset_examples<T, V>(self, v: T) -> Self
Sets the value of user_dataset_examples.
Example
use google_cloud_aiplatform_v1::model::Content;
let x = SupervisedTuningDataStats::new()
.set_user_dataset_examples([
Content::default()/* use setters */,
Content::default()/* use (different) setters */,
]);Sourcepub fn set_total_truncated_example_count<T: Into<i64>>(self, v: T) -> Self
pub fn set_total_truncated_example_count<T: Into<i64>>(self, v: T) -> Self
Sets the value of total_truncated_example_count.
Example
let x = SupervisedTuningDataStats::new().set_total_truncated_example_count(42);Sourcepub fn set_truncated_example_indices<T, V>(self, v: T) -> Self
pub fn set_truncated_example_indices<T, V>(self, v: T) -> Self
Sets the value of truncated_example_indices.
Example
let x = SupervisedTuningDataStats::new().set_truncated_example_indices([1, 2, 3]);Sourcepub fn set_dropped_example_reasons<T, V>(self, v: T) -> Self
pub fn set_dropped_example_reasons<T, V>(self, v: T) -> Self
Sets the value of dropped_example_reasons.
Example
let x = SupervisedTuningDataStats::new().set_dropped_example_reasons(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for SupervisedTuningDataStats
impl Clone for SupervisedTuningDataStats
Sourcefn clone(&self) -> SupervisedTuningDataStats
fn clone(&self) -> SupervisedTuningDataStats
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for SupervisedTuningDataStats
impl Debug for SupervisedTuningDataStats
Sourceimpl Default for SupervisedTuningDataStats
impl Default for SupervisedTuningDataStats
Sourcefn default() -> SupervisedTuningDataStats
fn default() -> SupervisedTuningDataStats
Sourceimpl Message for SupervisedTuningDataStats
impl Message for SupervisedTuningDataStats
impl StructuralPartialEq for SupervisedTuningDataStats