#[non_exhaustive]pub struct TimeSeriesDataPoint {
pub wall_time: Option<Timestamp>,
pub step: i64,
pub value: Option<Value>,
/* private fields */
}tensorboard-service only.Expand description
A TensorboardTimeSeries data point.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.wall_time: Option<Timestamp>Wall clock timestamp when this data point is generated by the end user.
step: i64Step index of this data point within the run.
value: Option<Value>Value of this time series data point.
Implementations
Sourceimpl TimeSeriesDataPoint
impl TimeSeriesDataPoint
Sourcepub fn set_wall_time<T>(self, v: T) -> Self
pub fn set_wall_time<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_wall_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_wall_time<T>(self, v: Option<T>) -> Self
Sourcepub fn set_value<T: Into<Option<Value>>>(self, v: T) -> Self
pub fn set_value<T: Into<Option<Value>>>(self, v: T) -> Self
Sets the value of value.
Note that all the setters affecting value are mutually
exclusive.
Example
use google_cloud_aiplatform_v1::model::Scalar;
let x = TimeSeriesDataPoint::new().set_value(Some(
google_cloud_aiplatform_v1::model::time_series_data_point::Value::Scalar(Scalar::default().into())));Sourcepub fn scalar(&self) -> Option<&Box<Scalar>>
pub fn scalar(&self) -> Option<&Box<Scalar>>
The value of value
if it holds a Scalar, None if the field is not set or
holds a different branch.
Sourcepub fn set_scalar<T: Into<Box<Scalar>>>(self, v: T) -> Self
pub fn set_scalar<T: Into<Box<Scalar>>>(self, v: T) -> Self
Sets the value of value
to hold a Scalar.
Note that all the setters affecting value are
mutually exclusive.
Example
use google_cloud_aiplatform_v1::model::Scalar;
let x = TimeSeriesDataPoint::new().set_scalar(Scalar::default()/* use setters */);
assert!(x.scalar().is_some());
assert!(x.tensor().is_none());
assert!(x.blobs().is_none());Sourcepub fn tensor(&self) -> Option<&Box<TensorboardTensor>>
pub fn tensor(&self) -> Option<&Box<TensorboardTensor>>
The value of value
if it holds a Tensor, None if the field is not set or
holds a different branch.
Sourcepub fn set_tensor<T: Into<Box<TensorboardTensor>>>(self, v: T) -> Self
pub fn set_tensor<T: Into<Box<TensorboardTensor>>>(self, v: T) -> Self
Sets the value of value
to hold a Tensor.
Note that all the setters affecting value are
mutually exclusive.
Example
use google_cloud_aiplatform_v1::model::TensorboardTensor;
let x = TimeSeriesDataPoint::new().set_tensor(TensorboardTensor::default()/* use setters */);
assert!(x.tensor().is_some());
assert!(x.scalar().is_none());
assert!(x.blobs().is_none());Sourcepub fn blobs(&self) -> Option<&Box<TensorboardBlobSequence>>
pub fn blobs(&self) -> Option<&Box<TensorboardBlobSequence>>
The value of value
if it holds a Blobs, None if the field is not set or
holds a different branch.
Sourcepub fn set_blobs<T: Into<Box<TensorboardBlobSequence>>>(self, v: T) -> Self
pub fn set_blobs<T: Into<Box<TensorboardBlobSequence>>>(self, v: T) -> Self
Sets the value of value
to hold a Blobs.
Note that all the setters affecting value are
mutually exclusive.
Example
use google_cloud_aiplatform_v1::model::TensorboardBlobSequence;
let x = TimeSeriesDataPoint::new().set_blobs(TensorboardBlobSequence::default()/* use setters */);
assert!(x.blobs().is_some());
assert!(x.scalar().is_none());
assert!(x.tensor().is_none());Trait Implementations
Sourceimpl Clone for TimeSeriesDataPoint
impl Clone for TimeSeriesDataPoint
Sourcefn clone(&self) -> TimeSeriesDataPoint
fn clone(&self) -> TimeSeriesDataPoint
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for TimeSeriesDataPoint
impl Debug for TimeSeriesDataPoint
Sourceimpl Default for TimeSeriesDataPoint
impl Default for TimeSeriesDataPoint
Sourcefn default() -> TimeSeriesDataPoint
fn default() -> TimeSeriesDataPoint
Sourceimpl Message for TimeSeriesDataPoint
impl Message for TimeSeriesDataPoint
Sourceimpl PartialEq for TimeSeriesDataPoint
impl PartialEq for TimeSeriesDataPoint
impl StructuralPartialEq for TimeSeriesDataPoint