#[non_exhaustive]pub struct TunedModel {
pub model: String,
pub endpoint: String,
pub checkpoints: Vec<TunedModelCheckpoint>,
/* private fields */
}gen-ai-tuning-service only.Expand description
The Model Registry Model and Online Prediction Endpoint associated with this TuningJob.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.model: StringOutput only. The resource name of the TunedModel. Format:
projects/{project}/locations/{location}/models/{model}@{version_id}
When tuning from a base model, the version ID will be 1.
For continuous tuning, if the provided tuned_model_display_name is set and different from parent model’s display name, the tuned model will have a new parent model with version 1. Otherwise the version id will be incremented by 1 from the last version ID in the parent model. E.g.,
projects/{project}/locations/{location}/models/{model}@{last_version_id + 1}
endpoint: StringOutput only. A resource name of an Endpoint. Format:
projects/{project}/locations/{location}/endpoints/{endpoint}.
checkpoints: Vec<TunedModelCheckpoint>Output only. The checkpoints associated with this TunedModel. This field is only populated for tuning jobs that enable intermediate checkpoints.
Implementations
Sourceimpl TunedModel
impl TunedModel
Sourcepub fn set_endpoint<T: Into<String>>(self, v: T) -> Self
pub fn set_endpoint<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_checkpoints<T, V>(self, v: T) -> Self
pub fn set_checkpoints<T, V>(self, v: T) -> Self
Sets the value of checkpoints.
Example
use google_cloud_aiplatform_v1::model::TunedModelCheckpoint;
let x = TunedModel::new()
.set_checkpoints([
TunedModelCheckpoint::default()/* use setters */,
TunedModelCheckpoint::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for TunedModel
impl Clone for TunedModel
Sourcefn clone(&self) -> TunedModel
fn clone(&self) -> TunedModel
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for TunedModel
impl Debug for TunedModel
Sourceimpl Default for TunedModel
impl Default for TunedModel
Sourcefn default() -> TunedModel
fn default() -> TunedModel
Sourceimpl PartialEq for TunedModel
impl PartialEq for TunedModel
impl StructuralPartialEq for TunedModel