#[non_exhaustive]pub struct VertexMultimodalDatasetDestination {
pub bigquery_destination: Option<BigQueryDestination>,
pub display_name: String,
/* private fields */
}Available on crate feature
job-service only.Expand description
The details for a Vertex Multimodal Dataset output.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.bigquery_destination: Option<BigQueryDestination>Optional. The destination of the underlying BigQuery table that will be created for the output Multimodal Dataset. If not specified, the BigQuery table will be created in a default BigQuery dataset.
display_name: StringOptional. Display name of the output dataset.
Implementations
Sourceimpl VertexMultimodalDatasetDestination
impl VertexMultimodalDatasetDestination
pub fn new() -> Self
Sourcepub fn set_bigquery_destination<T>(self, v: T) -> Selfwhere
T: Into<BigQueryDestination>,
pub fn set_bigquery_destination<T>(self, v: T) -> Selfwhere
T: Into<BigQueryDestination>,
Sets the value of bigquery_destination.
Example
ⓘ
use google_cloud_aiplatform_v1::model::BigQueryDestination;
let x = VertexMultimodalDatasetDestination::new().set_bigquery_destination(BigQueryDestination::default()/* use setters */);Sourcepub fn set_or_clear_bigquery_destination<T>(self, v: Option<T>) -> Selfwhere
T: Into<BigQueryDestination>,
pub fn set_or_clear_bigquery_destination<T>(self, v: Option<T>) -> Selfwhere
T: Into<BigQueryDestination>,
Sets or clears the value of bigquery_destination.
Example
ⓘ
use google_cloud_aiplatform_v1::model::BigQueryDestination;
let x = VertexMultimodalDatasetDestination::new().set_or_clear_bigquery_destination(Some(BigQueryDestination::default()/* use setters */));
let x = VertexMultimodalDatasetDestination::new().set_or_clear_bigquery_destination(None::<BigQueryDestination>);Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sets the value of display_name.
Example
ⓘ
let x = VertexMultimodalDatasetDestination::new().set_display_name("example");Trait Implementations
Sourceimpl Clone for VertexMultimodalDatasetDestination
impl Clone for VertexMultimodalDatasetDestination
Sourcefn clone(&self) -> VertexMultimodalDatasetDestination
fn clone(&self) -> VertexMultimodalDatasetDestination
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for VertexMultimodalDatasetDestination
impl Default for VertexMultimodalDatasetDestination
Sourcefn default() -> VertexMultimodalDatasetDestination
fn default() -> VertexMultimodalDatasetDestination
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for VertexMultimodalDatasetDestination
impl PartialEq for VertexMultimodalDatasetDestination
Sourcefn eq(&self, other: &VertexMultimodalDatasetDestination) -> bool
fn eq(&self, other: &VertexMultimodalDatasetDestination) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for VertexMultimodalDatasetDestination