#[non_exhaustive]pub struct CodeExecution { /* private fields */ }Available on crate features
gen-ai-cache-service or llm-utility-service or prediction-service or vertex-rag-service only.Expand description
Tool that executes code generated by the model, and automatically returns the result to the model.
See also ExecutableCodeand CodeExecutionResult which are input and output to this tool.
Implementations
Sourceimpl CodeExecution
impl CodeExecution