#[non_exhaustive]pub struct ParallelAiSearch {
pub api_key: String,
pub custom_configs: Option<Struct>,
/* private fields */
}gen-ai-cache-service or llm-utility-service or prediction-service or vertex-rag-service only.Expand description
ParallelAiSearch tool type. A tool that uses the Parallel.ai search engine for grounding.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.api_key: StringOptional. The API key for ParallelAiSearch. If an API key is not provided, the system will attempt to verify access by checking for an active Parallel.ai subscription through the Google Cloud Marketplace. See https://docs.parallel.ai/search/search-quickstart for more details.
custom_configs: Option<Struct>Optional. Custom configs for ParallelAiSearch.
This field can be used to pass any parameter from the Parallel.ai
Search API.
See the Parallel.ai documentation for the full list of available
parameters and their usage:
https://docs.parallel.ai/api-reference/search-beta/search
Currently only source_policy, excerpts, max_results, mode,
fetch_policy can be set via this field. For example:
{
“source_policy”: {
“include_domains”: [“google.com”, “wikipedia.org”],
“exclude_domains”: [“example.com”]
},
“fetch_policy”: {
“max_age_seconds”: 3600
}
}
Implementations
Sourceimpl ParallelAiSearch
impl ParallelAiSearch
Sourcepub fn set_api_key<T: Into<String>>(self, v: T) -> Self
pub fn set_api_key<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_custom_configs<T>(self, v: T) -> Self
pub fn set_custom_configs<T>(self, v: T) -> Self
Sets the value of custom_configs.
Example
use wkt::Struct;
let x = ParallelAiSearch::new().set_custom_configs(Struct::default()/* use setters */);Sourcepub fn set_or_clear_custom_configs<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_custom_configs<T>(self, v: Option<T>) -> Self
Sets or clears the value of custom_configs.
Example
use wkt::Struct;
let x = ParallelAiSearch::new().set_or_clear_custom_configs(Some(Struct::default()/* use setters */));
let x = ParallelAiSearch::new().set_or_clear_custom_configs(None::<Struct>);Trait Implementations
Sourceimpl Clone for ParallelAiSearch
impl Clone for ParallelAiSearch
Sourcefn clone(&self) -> ParallelAiSearch
fn clone(&self) -> ParallelAiSearch
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ParallelAiSearch
impl Debug for ParallelAiSearch
Sourceimpl Default for ParallelAiSearch
impl Default for ParallelAiSearch
Sourcefn default() -> ParallelAiSearch
fn default() -> ParallelAiSearch
Sourceimpl Message for ParallelAiSearch
impl Message for ParallelAiSearch
Sourceimpl PartialEq for ParallelAiSearch
impl PartialEq for ParallelAiSearch
impl StructuralPartialEq for ParallelAiSearch