pub struct FeaturestoreService { /* private fields */ }featurestore-service only.Expand description
Implements a client for the Vertex AI API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = FeaturestoreService::builder().build().await?;
let parent = "parent_value";
let mut list = client.list_featurestores()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
The service that handles CRUD and List for resources for Featurestore.
Configuration
To configure FeaturestoreService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://aiplatform.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
FeaturestoreService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap FeaturestoreService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl FeaturestoreService
impl FeaturestoreService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for FeaturestoreService.
let client = FeaturestoreService::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: FeaturestoreService + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: FeaturestoreService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn create_featurestore(&self) -> CreateFeaturestore
pub fn create_featurestore(&self) -> CreateFeaturestore
Creates a new Featurestore in a given project and location.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::model::Featurestore;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeaturestoreService, parent: &str
) -> Result<()> {
let response = client.create_featurestore()
.set_parent(parent)
.set_featurestore_id("featurestore_id_value")
.set_featurestore(
Featurestore::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_featurestore(&self) -> GetFeaturestore
pub fn get_featurestore(&self) -> GetFeaturestore
Gets details of a single Featurestore.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeaturestoreService, name: &str
) -> Result<()> {
let response = client.get_featurestore()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_featurestores(&self) -> ListFeaturestores
pub fn list_featurestores(&self) -> ListFeaturestores
Lists Featurestores in a given project and location.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeaturestoreService, parent: &str
) -> Result<()> {
let mut list = client.list_featurestores()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn update_featurestore(&self) -> UpdateFeaturestore
pub fn update_featurestore(&self) -> UpdateFeaturestore
Updates the parameters of a single Featurestore.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_aiplatform_v1::model::Featurestore;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeaturestoreService, name: &str
) -> Result<()> {
let response = client.update_featurestore()
.set_featurestore(
Featurestore::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_featurestore(&self) -> DeleteFeaturestore
pub fn delete_featurestore(&self) -> DeleteFeaturestore
Deletes a single Featurestore. The Featurestore must not contain any
EntityTypes or force must be set to true for the request to succeed.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeaturestoreService, name: &str
) -> Result<()> {
client.delete_featurestore()
.set_name(name)
.poller().until_done().await?;
Ok(())
}Sourcepub fn create_entity_type(&self) -> CreateEntityType
pub fn create_entity_type(&self) -> CreateEntityType
Creates a new EntityType in a given Featurestore.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::model::EntityType;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeaturestoreService, parent: &str
) -> Result<()> {
let response = client.create_entity_type()
.set_parent(parent)
.set_entity_type(
EntityType::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_entity_type(&self) -> GetEntityType
pub fn get_entity_type(&self) -> GetEntityType
Gets details of a single EntityType.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeaturestoreService, name: &str
) -> Result<()> {
let response = client.get_entity_type()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_entity_types(&self) -> ListEntityTypes
pub fn list_entity_types(&self) -> ListEntityTypes
Lists EntityTypes in a given Featurestore.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeaturestoreService, parent: &str
) -> Result<()> {
let mut list = client.list_entity_types()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn update_entity_type(&self) -> UpdateEntityType
pub fn update_entity_type(&self) -> UpdateEntityType
Updates the parameters of a single EntityType.
Example
use google_cloud_wkt::FieldMask;
use google_cloud_aiplatform_v1::model::EntityType;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeaturestoreService, name: &str
) -> Result<()> {
let response = client.update_entity_type()
.set_entity_type(
EntityType::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_entity_type(&self) -> DeleteEntityType
pub fn delete_entity_type(&self) -> DeleteEntityType
Deletes a single EntityType. The EntityType must not have any Features
or force must be set to true for the request to succeed.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeaturestoreService, name: &str
) -> Result<()> {
client.delete_entity_type()
.set_name(name)
.poller().until_done().await?;
Ok(())
}Sourcepub fn create_feature(&self) -> CreateFeature
pub fn create_feature(&self) -> CreateFeature
Creates a new Feature in a given EntityType.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::model::Feature;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeaturestoreService, parent: &str
) -> Result<()> {
let response = client.create_feature()
.set_parent(parent)
.set_feature_id("feature_id_value")
.set_feature(
Feature::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn batch_create_features(&self) -> BatchCreateFeatures
pub fn batch_create_features(&self) -> BatchCreateFeatures
Creates a batch of Features in a given EntityType.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeaturestoreService
) -> Result<()> {
let response = client.batch_create_features()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_feature(&self) -> GetFeature
pub fn get_feature(&self) -> GetFeature
Gets details of a single Feature.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeaturestoreService, name: &str
) -> Result<()> {
let response = client.get_feature()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_features(&self) -> ListFeatures
pub fn list_features(&self) -> ListFeatures
Lists Features in a given EntityType.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeaturestoreService, parent: &str
) -> Result<()> {
let mut list = client.list_features()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn update_feature(&self) -> UpdateFeature
pub fn update_feature(&self) -> UpdateFeature
Updates the parameters of a single Feature.
Example
use google_cloud_wkt::FieldMask;
use google_cloud_aiplatform_v1::model::Feature;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeaturestoreService, name: &str
) -> Result<()> {
let response = client.update_feature()
.set_feature(
Feature::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_feature(&self) -> DeleteFeature
pub fn delete_feature(&self) -> DeleteFeature
Deletes a single Feature.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeaturestoreService, name: &str
) -> Result<()> {
client.delete_feature()
.set_name(name)
.poller().until_done().await?;
Ok(())
}Sourcepub fn import_feature_values(&self) -> ImportFeatureValues
pub fn import_feature_values(&self) -> ImportFeatureValues
Imports Feature values into the Featurestore from a source storage.
The progress of the import is tracked by the returned operation. The imported features are guaranteed to be visible to subsequent read operations after the operation is marked as successfully done.
If an import operation fails, the Feature values returned from reads and exports may be inconsistent. If consistency is required, the caller must retry the same import request again and wait till the new operation returned is marked as successfully done.
There are also scenarios where the caller can cause inconsistency.
- Source data for import contains multiple distinct Feature values for the same entity ID and timestamp.
- Source is modified during an import. This includes adding, updating, or removing source data and/or metadata. Examples of updating metadata include but are not limited to changing storage location, storage class, or retention policy.
- Online serving cluster is under-provisioned.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeaturestoreService
) -> Result<()> {
let response = client.import_feature_values()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn batch_read_feature_values(&self) -> BatchReadFeatureValues
pub fn batch_read_feature_values(&self) -> BatchReadFeatureValues
Batch reads Feature values from a Featurestore.
This API enables batch reading Feature values, where each read instance in the batch may read Feature values of entities from one or more EntityTypes. Point-in-time correctness is guaranteed for Feature values of each read instance as of each instance’s read timestamp.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeaturestoreService
) -> Result<()> {
let response = client.batch_read_feature_values()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn export_feature_values(&self) -> ExportFeatureValues
pub fn export_feature_values(&self) -> ExportFeatureValues
Exports Feature values from all the entities of a target EntityType.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeaturestoreService
) -> Result<()> {
let response = client.export_feature_values()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_feature_values(&self) -> DeleteFeatureValues
pub fn delete_feature_values(&self) -> DeleteFeatureValues
Delete Feature values from Featurestore.
The progress of the deletion is tracked by the returned operation. The deleted feature values are guaranteed to be invisible to subsequent read operations after the operation is marked as successfully done.
If a delete feature values operation fails, the feature values returned from reads and exports may be inconsistent. If consistency is required, the caller must retry the same delete request again and wait till the new operation returned is marked as successfully done.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeaturestoreService
) -> Result<()> {
let response = client.delete_feature_values()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn search_features(&self) -> SearchFeatures
pub fn search_features(&self) -> SearchFeatures
Searches Features matching a query in a given project.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeaturestoreService
) -> Result<()> {
let mut list = client.search_features()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn list_locations(&self) -> ListLocations
pub fn list_locations(&self) -> ListLocations
Lists information about the supported locations for this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeaturestoreService
) -> Result<()> {
let mut list = client.list_locations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_location(&self) -> GetLocation
pub fn get_location(&self) -> GetLocation
Gets information about a location.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeaturestoreService
) -> Result<()> {
let response = client.get_location()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn set_iam_policy(&self) -> SetIamPolicy
pub fn set_iam_policy(&self) -> SetIamPolicy
Sets the access control policy on the specified resource. Replaces any existing policy.
Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED
errors.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeaturestoreService
) -> Result<()> {
let response = client.set_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_iam_policy(&self) -> GetIamPolicy
pub fn get_iam_policy(&self) -> GetIamPolicy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeaturestoreService
) -> Result<()> {
let response = client.get_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn test_iam_permissions(&self) -> TestIamPermissions
pub fn test_iam_permissions(&self) -> TestIamPermissions
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of
permissions, not a NOT_FOUND error.
Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeaturestoreService
) -> Result<()> {
let response = client.test_iam_permissions()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeaturestoreService
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeaturestoreService
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeaturestoreService
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeaturestoreService
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn wait_operation(&self) -> WaitOperation
pub fn wait_operation(&self) -> WaitOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &FeaturestoreService
) -> Result<()> {
let response = client.wait_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Trait Implementations
Sourceimpl Clone for FeaturestoreService
impl Clone for FeaturestoreService
Sourcefn clone(&self) -> FeaturestoreService
fn clone(&self) -> FeaturestoreService
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more