pub struct SessionService { /* private fields */ }session-service only.Expand description
Implements a client for the Vertex AI API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = SessionService::builder().build().await?;
let parent = "parent_value";
let mut list = client.list_sessions()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
The service that manages Vertex Session related resources.
Configuration
To configure SessionService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://aiplatform.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
SessionService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap SessionService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl SessionService
impl SessionService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for SessionService.
let client = SessionService::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: SessionService + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: SessionService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn create_session(&self) -> CreateSession
pub fn create_session(&self) -> CreateSession
Creates a new Session.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::model::Session;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &SessionService, parent: &str
) -> Result<()> {
let response = client.create_session()
.set_parent(parent)
.set_session_id("session_id_value")
.set_session(
Session::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_session(&self) -> GetSession
pub fn get_session(&self) -> GetSession
Sourcepub fn list_sessions(&self) -> ListSessions
pub fn list_sessions(&self) -> ListSessions
Lists Sessions in a given reasoning engine.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &SessionService, parent: &str
) -> Result<()> {
let mut list = client.list_sessions()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn update_session(&self) -> UpdateSession
pub fn update_session(&self) -> UpdateSession
Updates the specific Session.
Example
use google_cloud_wkt::FieldMask;
use google_cloud_aiplatform_v1::model::Session;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &SessionService, name: &str
) -> Result<()> {
let response = client.update_session()
.set_session(
Session::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_session(&self) -> DeleteSession
pub fn delete_session(&self) -> DeleteSession
Deletes details of the specific Session.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &SessionService, name: &str
) -> Result<()> {
client.delete_session()
.set_name(name)
.poller().until_done().await?;
Ok(())
}Sourcepub fn list_events(&self) -> ListEvents
pub fn list_events(&self) -> ListEvents
Lists Events in a given session.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &SessionService, parent: &str
) -> Result<()> {
let mut list = client.list_events()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn append_event(&self) -> AppendEvent
pub fn append_event(&self) -> AppendEvent
Appends an event to a given session.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &SessionService
) -> Result<()> {
let response = client.append_event()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_locations(&self) -> ListLocations
pub fn list_locations(&self) -> ListLocations
Lists information about the supported locations for this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &SessionService
) -> Result<()> {
let mut list = client.list_locations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_location(&self) -> GetLocation
pub fn get_location(&self) -> GetLocation
Gets information about a location.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &SessionService
) -> Result<()> {
let response = client.get_location()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn set_iam_policy(&self) -> SetIamPolicy
pub fn set_iam_policy(&self) -> SetIamPolicy
Sets the access control policy on the specified resource. Replaces any existing policy.
Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED
errors.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &SessionService
) -> Result<()> {
let response = client.set_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_iam_policy(&self) -> GetIamPolicy
pub fn get_iam_policy(&self) -> GetIamPolicy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &SessionService
) -> Result<()> {
let response = client.get_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn test_iam_permissions(&self) -> TestIamPermissions
pub fn test_iam_permissions(&self) -> TestIamPermissions
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of
permissions, not a NOT_FOUND error.
Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &SessionService
) -> Result<()> {
let response = client.test_iam_permissions()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &SessionService
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &SessionService
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &SessionService
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &SessionService
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn wait_operation(&self) -> WaitOperation
pub fn wait_operation(&self) -> WaitOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_aiplatform_v1::Result;
async fn sample(
client: &SessionService
) -> Result<()> {
let response = client.wait_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Trait Implementations
Sourceimpl Clone for SessionService
impl Clone for SessionService
Sourcefn clone(&self) -> SessionService
fn clone(&self) -> SessionService
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more