#[non_exhaustive]pub struct SelectTimeRangeAndFeature {
pub impacted_feature_count: i64,
pub offline_storage_modified_entity_row_count: i64,
pub online_storage_modified_entity_count: i64,
/* private fields */
}featurestore-service only.Expand description
Response message if the request uses the SelectTimeRangeAndFeature option.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.impacted_feature_count: i64The count of the features or columns impacted. This is the same as the feature count in the request.
offline_storage_modified_entity_row_count: i64The count of modified entity rows in the offline storage. Each row corresponds to the combination of an entity ID and a timestamp. One entity ID can have multiple rows in the offline storage. Within each row, only the features specified in the request are deleted.
online_storage_modified_entity_count: i64The count of modified entities in the online storage. Each entity ID corresponds to one entity. Within each entity, only the features specified in the request are deleted.
Implementations
Sourceimpl SelectTimeRangeAndFeature
impl SelectTimeRangeAndFeature
pub fn new() -> Self
Sourcepub fn set_impacted_feature_count<T: Into<i64>>(self, v: T) -> Self
pub fn set_impacted_feature_count<T: Into<i64>>(self, v: T) -> Self
Sets the value of impacted_feature_count.
Example
let x = SelectTimeRangeAndFeature::new().set_impacted_feature_count(42);Sourcepub fn set_offline_storage_modified_entity_row_count<T: Into<i64>>(
self,
v: T,
) -> Self
pub fn set_offline_storage_modified_entity_row_count<T: Into<i64>>( self, v: T, ) -> Self
Sets the value of offline_storage_modified_entity_row_count.
Example
let x = SelectTimeRangeAndFeature::new().set_offline_storage_modified_entity_row_count(42);Sourcepub fn set_online_storage_modified_entity_count<T: Into<i64>>(
self,
v: T,
) -> Self
pub fn set_online_storage_modified_entity_count<T: Into<i64>>( self, v: T, ) -> Self
Sets the value of online_storage_modified_entity_count.
Example
let x = SelectTimeRangeAndFeature::new().set_online_storage_modified_entity_count(42);Trait Implementations
Sourceimpl Clone for SelectTimeRangeAndFeature
impl Clone for SelectTimeRangeAndFeature
Sourcefn clone(&self) -> SelectTimeRangeAndFeature
fn clone(&self) -> SelectTimeRangeAndFeature
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more