#[non_exhaustive]pub enum Destination {
GcsDestination(Box<GcsDestination>),
}Available on crate feature
dataset-service only.Expand description
The destination of the output.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
GcsDestination(Box<GcsDestination>)
The Google Cloud Storage location where the output is to be written to.
In the given directory a new directory will be created with name:
export-data-<dataset-display-name>-<timestamp-of-export-call> where
timestamp is in YYYY-MM-DDThh:mm:ss.sssZ ISO-8601 format. All export
output will be written into that directory. Inside that directory,
annotations with the same schema will be grouped into sub directories
which are named with the corresponding annotations’ schema title. Inside
these sub directories, a schema.yaml will be created to describe the
output format.