CompletionStats

Struct CompletionStats 

#[non_exhaustive]
pub struct CompletionStats { pub successful_count: i64, pub failed_count: i64, pub incomplete_count: i64, pub successful_forecast_point_count: i64, /* private fields */ }
Available on crate feature job-service only.
Success and error statistics of processing multiple entities (for example, DataItems or structured data rows) in batch.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
successful_count: i64

Output only. The number of entities that had been processed successfully.

failed_count: i64

Output only. The number of entities for which any error was encountered.

incomplete_count: i64

Output only. In cases when enough errors are encountered a job, pipeline, or operation may be failed as a whole. Below is the number of entities for which the processing had not been finished (either in successful or failed state). Set to -1 if the number is unknown (for example, the operation failed before the total entity number could be collected).

successful_forecast_point_count: i64

Output only. The number of the successful forecast points that are generated by the forecasting model. This is ONLY used by the forecasting batch prediction.

Implementations

Source

impl CompletionStats

pub fn new() -> Self

pub fn set_successful_count<T: Into<i64>>(self, v: T) -> Self

Sets the value of successful_count.

Example
let x = CompletionStats::new().set_successful_count(42);
pub fn set_failed_count<T: Into<i64>>(self, v: T) -> Self

Sets the value of failed_count.

Example
let x = CompletionStats::new().set_failed_count(42);
pub fn set_incomplete_count<T: Into<i64>>(self, v: T) -> Self

Sets the value of incomplete_count.

Example
let x = CompletionStats::new().set_incomplete_count(42);
pub fn set_successful_forecast_point_count<T: Into<i64>>(self, v: T) -> Self

Sets the value of successful_forecast_point_count.

Example
let x = CompletionStats::new().set_successful_forecast_point_count(42);